@@ -73,6 +73,7 @@ QObject(parent), parent(parent)
     createAction(tr("F2"),":/icons/iconInc16x16",tr("&Inc. Elevation"),"aMap3DZoomPlus",tr("Make elevations on the map higher as they are."));
     createAction(tr("F3"),":/icons/iconDec16x16",tr("&Dec. Elevation"),"aMap3DZoomMinus",tr("Make elevations on the map lower as they are."));
     createAction(tr("F4"),":/icons/iconLight16x16",tr("&Lighting On/Off"), "aMap3DLighting",tr("Turn on/off lighting."));
+    createAction(tr("F5"),":/icons/iconTrack16x16",tr("&Trackmode"), "aMap3DTrackmode",tr("Glue point of view to track."));
 #endif
     //
     createAction(tr("F5"), ":/icons/iconAdd16x16", tr("&New Waypoint"), "aNewWpt", tr("Create a new user waypoint. The default position will be the current cursor position."));
@@ -86,7 +87,7 @@ QObject(parent), parent(parent)
     //
     createAction(tr("F5"), ":/icons/iconAdd16x16", tr("Combine &Tracks"), "aCombineTrack", tr("Combine multiple selected tracks to one."));
     createAction(tr("F6"), ":/icons/iconEdit16x16", tr("&Edit Track"), "aEditTrack", tr("Toggle track edit dialog."));
-    createAction(tr("F7"), ":/icons/iconEditCut16x16", tr("&Cut Tracks"), "aCutTrack", tr("Cut a track into pieces."));
+    createAction(tr("F7"), ":/icons/iconEditCut16x16", tr("&Split Track"), "aCutTrack", tr("Split a track into pieces."));
     createAction(tr("F8"), ":/icons/iconSelect16x16", tr("&Select Points"), "aSelTrack", tr("Select track points by rectangle."));
     createAction(tr("F9"), ":/icons/iconUpload16x16", tr("U&pload"), "aUploadTrack", tr("Upload tracks to device."));
     createAction(tr("F10"), ":/icons/iconDownload16x16", tr("Down&load"), "aDownloadTrack", tr("Download tracks from device."));
@@ -111,8 +112,8 @@ QObject(parent), parent(parent)
     createAction(tr("F10"), ":/icons/iconDownload16x16", tr("Down&load"), "aDownloadRoute", tr("Download routes from device."));
     //
 
-    createAction(tr("+"), ":/icons/editcopy.png", tr("&Zoom in"), "aZoomIn", tr("Zoom's into the Map."));
-    createAction(tr("-"), ":/icons/editcopy.png", tr("&Zoom out"), "aZoomOut", tr("Zoom's out of the Map."));
+    createAction(tr("+"), ":/icons/zoomin.png", tr("&Zoom in"), "aZoomIn", tr("Zoom's into the Map."));
+    createAction(tr("-"), ":/icons/zoomout.png", tr("&Zoom out"), "aZoomOut", tr("Zoom's out of the Map."));
     createAction(QKeySequence (Qt::ALT + Qt::Key_Left).toString(), ":/icons/editcopy.png", tr("&Move left"), "aMoveLeft", tr("Move to the left side."));
     createAction(QKeySequence (Qt::ALT + Qt::Key_Right).toString(), ":/icons/editcopy.png", tr("&Move right"), "aMoveRight", tr("Move to the right side."));
     createAction(QKeySequence (Qt::ALT + Qt::Key_Up).toString(), ":/icons/editcopy.png", tr("&Move up"), "aMoveUp", tr("Move up."));
@@ -136,7 +137,8 @@ const QString& name,
 const QString& actionName,
 const QString& toolTip)
 {
-    if (findChild<QAction *> (actionName)) {
+    if (findChild<QAction *> (actionName))
+    {
         qDebug()
             << tr("Action with the name '%1' already registered. Please choose an other name.").arg(actionName);
         return;
@@ -163,7 +165,8 @@ QAction *CActions::getAction(const QString& actionObjectName)
     QAction *tmpAction = findChild<QAction *> (actionObjectName);
     if (tmpAction)
         return tmpAction;
-    else {
+    else
+    {
         qDebug()
             << tr("Action with name '%1' not found. %2").arg(actionObjectName).arg(Q_FUNC_INFO);
         return new QAction(this);
@@ -341,7 +344,8 @@ void CActions::funcEditMap()
 {
 
     CMapDB::self().editMap();
-    if (CCreateMapGeoTiff::self()) {
+    if (CCreateMapGeoTiff::self())
+    {
         // setEnabled(false); // not finished
         connect(CCreateMapGeoTiff::self(), SIGNAL(destroyed(QObject*)), this, SLOT(slotEnable()));
     }
@@ -384,7 +388,8 @@ void CActions::funcMap3DZoomPlus()
 {
 #ifdef PLOT_3D
     CMap3DWidget * map = CMapDB::self().getMap3D();
-    if(map) {
+    if(map)
+    {
         map->eleZoomIn();
     }
 #endif
@@ -395,7 +400,8 @@ void CActions::funcMap3DZoomMinus()
 {
 #ifdef PLOT_3D
     CMap3DWidget * map = CMapDB::self().getMap3D();
-    if(map) {
+    if(map)
+    {
         map->eleZoomOut();
     }
 #endif
@@ -415,12 +421,24 @@ void CActions::funcMap3DMode()
 {
 #ifdef PLOT_3D
     CMap3DWidget * map = CMapDB::self().getMap3D();
-    if(map) {
+    if(map)
+    {
         map->changeMode();
     }
 #endif
 }
 
+void CActions::funcMap3DTrackmode()
+{
+#ifdef PLOT_3D
+    CMap3DWidget * map = CMapDB::self().getMap3D();
+    if(map)
+    {
+        map->changeTrackmode();
+    }
+#endif
+}
+
 
 void CActions::funcEditWpt()
 {
@@ -503,7 +521,8 @@ void CActions::funcTrackPurgeSelection()
 void CActions::funcDeleteTrackSelection()
 {
     CTrack *track = CTrackDB::self().highlightedTrack();
-    if (track) {
+    if (track)
+    {
         CUndoStack::getInstance()->beginMacro(tr("Delete Selection"));
         CUndoStack::getInstance()->push(new CTrackUndoCommandPurgePts(track));
         CUndoStack::getInstance()->push(new CTrackUndoCommandDeletePts(track));
