@@ -51,6 +51,13 @@ CCreateMapGeoTiff::CCreateMapGeoTiff(QWidget * parent)
     toolReload->setIcon(QPixmap(":/icons/iconReload16x16"));
     toolOutFile->setIcon(QPixmap(":/icons/iconFileSave16x16.png"));
 
+    helpStep1->setHelp(tr("Load Raster Map"),
+        tr("This dialog allows you to georeference raster map files. As pre-requisite you need a set of reference points and the projection for those points. You will get best results if the projection of the points is also the projection of the map. In most cases this is mercator. It is recommended to shift the reference point to WGS84 datum, right from the beginning."));
+    helpStep2->setHelp(tr("Add Reference Points"),
+        trUtf8("The next stage is to add known reference points. Simply add reference points to the map and enter their latitude / longitude (WGS84) or the easting and northing [m] in the table. Next you move the point to the correct location on the map.\n\ncoordinate formats:\n\xe2\x80\xa2 \"N49\xc2\xb0 10.234 E12\xc2\xb0 01.456\"\n\xe2\x80\xa2 \"12.193172   46.575377\"\n\xe2\x80\xa2 \"285000 5162000\""));
+    helpStep3->setHelp(tr("Reference Map"),
+        tr("Now QLandkarte GT will reference your file with the help of the GDAL tools. Watch the progress in the output browser."));
+
     connect(pushOpenFile, SIGNAL(clicked()), this, SLOT(slotOpenFile()));
     connect(toolReload, SIGNAL(clicked()), this, SLOT(slotReload()));
     connect(toolOutFile, SIGNAL(clicked()), this, SLOT(slotOutFile()));
@@ -95,7 +102,8 @@ CCreateMapGeoTiff::~CCreateMapGeoTiff()
 
 void CCreateMapGeoTiff::selRefPointByKey(const quint32 key)
 {
-    if(refpts.contains(key)) {
+    if(refpts.contains(key))
+    {
         refpt_t& pt = refpts[key];
         treeWidget->scrollToItem(pt.item);
         treeWidget->setCurrentItem(pt.item);
@@ -107,7 +115,8 @@ int CCreateMapGeoTiff::getNumberOfGCPs()
 {
     int n = 0;
     int mode = comboMode->itemData(comboMode->currentIndex()).toInt();
-    switch(mode) {
+    switch(mode)
+    {
         case 1:
             n = 3;
             break;
@@ -131,7 +140,7 @@ void CCreateMapGeoTiff::enableStep2()
     toolReload->setEnabled(true);
     labelStep2->setEnabled(true);
     treeWidget->setEnabled(true);
-    labelDoc2->setEnabled(true);
+    helpStep2->setEnabled(true);
     pushAddRef->setEnabled(true);
     pushLoadRef->setEnabled(true);
     pushGridTool->setEnabled(true);
@@ -143,7 +152,7 @@ void CCreateMapGeoTiff::enableStep3()
 {
     labelStep3->setEnabled(true);
     textBrowser->setEnabled(true);
-    labelDoc3->setEnabled(true);
+    helpStep3->setEnabled(true);
 }
 
 
@@ -176,7 +185,8 @@ void CCreateMapGeoTiff::slotOpenFile()
     sizeOfInputFile = QSize(dataset->GetRasterXSize(), dataset->GetRasterYSize());
 
     QString proj = dataset->GetGCPProjection();
-    if(!proj.isEmpty()) {
+    if(!proj.isEmpty())
+    {
 
         strncpy(str, dataset->GetGCPProjection(), sizeof(str));
         OGRSpatialReference oSRS;
@@ -222,7 +232,8 @@ void CCreateMapGeoTiff::slotReload()
     sizeOfInputFile = QSize(dataset->GetRasterXSize(), dataset->GetRasterYSize());
 
     QString proj = dataset->GetGCPProjection();
-    if(!proj.isEmpty()) {
+    if(!proj.isEmpty())
+    {
         strncpy(str, dataset->GetGCPProjection(), sizeof(str));
         OGRSpatialReference oSRS;
         oSRS.importFromWkt(&ptr);
@@ -263,7 +274,8 @@ void CCreateMapGeoTiff::slotAddRef()
     treeWidget->addTopLevelItem(pt.item);
 
     treeWidget->header()->setResizeMode(0,QHeaderView::Interactive);
-    for(int i=0; i < eMaxColumn - 1; ++i) {
+    for(int i=0; i < eMaxColumn - 1; ++i)
+    {
         treeWidget->resizeColumnToContents(i);
     }
 
@@ -291,7 +303,8 @@ void CCreateMapGeoTiff::addRef(double x, double y, double u, double v)
     treeWidget->addTopLevelItem(pt.item);
 
     treeWidget->header()->setResizeMode(0,QHeaderView::Interactive);
-    for(int i=0; i < eMaxColumn - 1; ++i) {
+    for(int i=0; i < eMaxColumn - 1; ++i)
+    {
         treeWidget->resizeColumnToContents(i);
     }
 
@@ -302,11 +315,13 @@ void CCreateMapGeoTiff::addRef(double x, double y, double u, double v)
 
 void CCreateMapGeoTiff::keyPressEvent(QKeyEvent * e)
 {
-    if(e->key() == Qt::Key_Delete) {
+    if(e->key() == Qt::Key_Delete)
+    {
         slotDelRef();
         e->accept();
     }
-    else {
+    else
+    {
         QWidget::keyPressEvent(e);
     }
 }
@@ -317,7 +332,8 @@ void CCreateMapGeoTiff::slotDelRef()
     QList<QTreeWidgetItem*> items = treeWidget->selectedItems();
     QTreeWidgetItem * item;
 
-    foreach(item, items) {
+    foreach(item, items)
+    {
         refpts.remove(item->data(eLabel,Qt::UserRole).toUInt());
         delete item;
     }
@@ -335,15 +351,18 @@ void CCreateMapGeoTiff::slotLoadRef()
     if(filename.isEmpty()) return;
 
     QFileInfo fi(filename);
-    if(fi.suffix() == "gcp") {
+    if(fi.suffix() == "gcp")
+    {
         loadGCP(filename);
     }
-    else if(fi.suffix() == "tab") {
+    else if(fi.suffix() == "tab")
+    {
         loadTAB(filename);
     }
 
     treeWidget->header()->setResizeMode(0,QHeaderView::Interactive);
-    for(int i=0; i < eMaxColumn - 1; ++i) {
+    for(int i=0; i < eMaxColumn - 1; ++i)
+    {
         treeWidget->resizeColumnToContents(i);
     }
 
@@ -360,12 +379,15 @@ void CCreateMapGeoTiff::loadGCP(const QString& filename)
     QFile file(filename);
     file.open(QIODevice::ReadOnly);
     QString line = QString::fromUtf8(file.readLine());
-    if(line.trimmed() == "#V1.0") {
+    if(line.trimmed() == "#V1.0")
+    {
         QRegExp re1("^-gcp\\s(-{0,1}[0-9]+)\\s(-{0,1}[0-9]+)\\s(.*)$");
         QRegExp re2("^-a_srs\\s(.*)$");
 
-        while(1) {
-            if(re1.exactMatch(line)) {
+        while(1)
+        {
+            if(re1.exactMatch(line))
+            {
                 refpt_t& pt     = refpts[++refcnt];
                 pt.item         = new QTreeWidgetItem();
 
@@ -381,7 +403,8 @@ void CCreateMapGeoTiff::loadGCP(const QString& filename)
 
                 treeWidget->addTopLevelItem(pt.item);
             }
-            else if(re2.exactMatch(line)) {
+            else if(re2.exactMatch(line))
+            {
                 lineProjection->setText(re2.cap(1).trimmed());
             }
 
@@ -389,22 +412,27 @@ void CCreateMapGeoTiff::loadGCP(const QString& filename)
             line = QString::fromUtf8(file.readLine());
         }
     }
-    else {
+    else
+    {
         QRegExp re1("^-gcp\\s(.*)\\s(-{0,1}[0-9]+)\\s(-{0,1}[0-9]+)\\s(.*)$");
         QRegExp re2("^-proj\\s(.*)$");
 
-        while(1) {
-            if(re1.exactMatch(line)) {
+        while(1)
+        {
+            if(re1.exactMatch(line))
+            {
                 refpt_t& pt     = refpts[++refcnt];
                 pt.item         = new QTreeWidgetItem();
 
                 pt.item->setFlags(Qt::ItemIsEditable|Qt::ItemIsEnabled|Qt::ItemIsSelectable);
                 pt.item->setData(eLabel,Qt::UserRole,refcnt);
                 QString label = re1.cap(4).trimmed();
-                if(label.isEmpty()) {
+                if(label.isEmpty())
+                {
                     pt.item->setText(eLabel,tr("Ref %1").arg(refcnt));
                 }
-                else {
+                else
+                {
                     pt.item->setText(eLabel,label);
                 }
                 pt.item->setText(eLonLat,re1.cap(1));
@@ -416,7 +444,8 @@ void CCreateMapGeoTiff::loadGCP(const QString& filename)
 
                 treeWidget->addTopLevelItem(pt.item);
             }
-            else if(re2.exactMatch(line)) {
+            else if(re2.exactMatch(line))
+            {
                 lineProjection->setText(re2.cap(1).trimmed());
             }
 
@@ -443,7 +472,8 @@ void CCreateMapGeoTiff::loadTAB(const QString& filename)
     adfGeoTransform[4] = 0.0;
     adfGeoTransform[5] = 1.0;
 
-    if(GDALReadTabFile(filename.toLocal8Bit(),adfGeoTransform,&pszTabWKT,&n,&gcpm)) {
+    if(GDALReadTabFile(filename.toLocal8Bit(),adfGeoTransform,&pszTabWKT,&n,&gcpm))
+    {
 
         gdalGCP2RefPt(gcpm,n);
 
@@ -460,7 +490,8 @@ void CCreateMapGeoTiff::loadTAB(const QString& filename)
 void CCreateMapGeoTiff::gdalGCP2RefPt(const GDAL_GCP* gcps, int n)
 {
     int i;
-    if (n) for(i=0;i<n;i++) {
+    if (n) for(i=0;i<n;i++)
+    {
         refpt_t& pt     = refpts[++refcnt];
         pt.item         = new QTreeWidgetItem();
 
@@ -468,10 +499,12 @@ void CCreateMapGeoTiff::gdalGCP2RefPt(const GDAL_GCP* gcps, int n)
 
         pt.item->setData(eLabel,Qt::UserRole,refcnt);
         QString label = gcps[i].pszInfo;
-        if(label.isEmpty()) {
+        if(label.isEmpty())
+        {
             pt.item->setText(eLabel,tr("Ref %1").arg(refcnt));
         }
-        else {
+        else
+        {
             pt.item->setText(eLabel,label);
         }
         pt.item->setText(eLonLat,QString("%1 %2").arg(gcps[i].dfGCPX,0,'f',6).arg(gcps[i].dfGCPY,0,'f',6));
@@ -500,17 +533,21 @@ void CCreateMapGeoTiff::slotSaveRef()
     qDebug() << filename;
     QFileInfo fi(filename);
 
-    if((filter == "Ref. points (*.gcp)") && (fi.suffix() != "gcp")) {
+    if((filter == "Ref. points (*.gcp)") && (fi.suffix() != "gcp"))
+    {
         filename += ".gcp";
     }
-    else if((filter == "Mapinfo (*.tab)") && (fi.suffix() != "tab")) {
+    else if((filter == "Mapinfo (*.tab)") && (fi.suffix() != "tab"))
+    {
         filename += ".tab";
     }
 
-    if(filter == "Ref. points (*.gcp)") {
+    if(filter == "Ref. points (*.gcp)")
+    {
         saveGCP(filename);
     }
-    else if(filter == "Mapinfo (*.tab)") {
+    else if(filter == "Mapinfo (*.tab)")
+    {
         saveTAB(filename);
     }
 
@@ -528,7 +565,8 @@ void CCreateMapGeoTiff::saveGCP(const QString& filename)
     file.write(QString("#V1.0\n").toUtf8());
 
     QString projection = lineProjection->text().trimmed();
-    if(projection.isEmpty()) {
+    if(projection.isEmpty())
+    {
         projection = "+proj=merc +ellps=WGS84 +datum=WGS84 +no_defs";
     }
 
@@ -539,7 +577,8 @@ void CCreateMapGeoTiff::saveGCP(const QString& filename)
     file.write(args.join(" ").toUtf8());
 
     QMap<quint32,refpt_t>::iterator refpt = refpts.begin();
-    while(refpt != refpts.end()) {
+    while(refpt != refpts.end())
+    {
         args.clear();
         args << "-gcp";
         args << QString::number(refpt->x,'f',0);
@@ -603,7 +642,8 @@ void CCreateMapGeoTiff::slotGoOn()
 
     // get / store target projection
     QString projection = lineProjection->text();
-    if(projection.isEmpty()) {
+    if(projection.isEmpty())
+    {
         projection = "+proj=merc +ellps=WGS84 +datum=WGS84 +no_defs";
     }
     islonlat = projection.contains("longlat");
@@ -618,7 +658,8 @@ void CCreateMapGeoTiff::slotGoOn()
     x1 = x2 = y1 = y2 = u1 = u2 = v1 = v2 = 0;
 
     QMap<quint32,refpt_t>::iterator refpt = refpts.begin();
-    while(refpt != refpts.end()) {
+    while(refpt != refpts.end())
+    {
         float lon = 0, lat = 0;
         args << "-gcp";
 
@@ -627,13 +668,17 @@ void CCreateMapGeoTiff::slotGoOn()
 
         args << QString::number(refpt->x,'f',0);
         args << QString::number(refpt->y,'f',0);
-        if(islonlat) {
-            if(!GPS_Math_Str_To_Deg(refpt->item->text(eLonLat), lon, lat)) {
+        if(islonlat)
+        {
+            if(!GPS_Math_Str_To_Deg(refpt->item->text(eLonLat), lon, lat))
+            {
                 return;
             }
         }
-        else {
-            if(!GPS_Math_Str_To_LongLat(refpt->item->text(eLonLat), lon, lat, projection)) {
+        else
+        {
+            if(!GPS_Math_Str_To_LongLat(refpt->item->text(eLonLat), lon, lat, projection))
+            {
                 return;
             }
         }
@@ -648,7 +693,8 @@ void CCreateMapGeoTiff::slotGoOn()
 
     // as gdalwarp needs 3 GCPs at least we add an artificial one on two GCPs
                                  /* use square pixels */
-    if ( treeWidget->topLevelItemCount() == 2 ) {
+    if ( treeWidget->topLevelItemCount() == 2 )
+    {
         double adfGeoTransform[6];
         double dx, dy, dX, dY, delta;
         double a, b;
@@ -661,7 +707,8 @@ void CCreateMapGeoTiff::slotGoOn()
 
         delta = dx * dx + dy * dy;
 
-        if (delta < 1 ) {        /* pixel */
+        if (delta < 1 )          /* pixel */
+        {
             QMessageBox::warning(0,tr("Error ..."), tr("Reference points are too close."), QMessageBox::Abort, QMessageBox::Abort);
             return;
         }
@@ -719,26 +766,31 @@ void CCreateMapGeoTiff::slotStdout()
 void CCreateMapGeoTiff::slotFinished( int exitCode, QProcess::ExitStatus status)
 {
     qDebug() << exitCode << status;
-    if(exitCode != 0) {
+    if(exitCode != 0)
+    {
         textBrowser->append(tr("Failed!\n"));
         cleanupTmpFiles();
         return;
     }
 
-    if(state == eTranslate) {
+    if(state == eTranslate)
+    {
         IMap& map = CMapDB::self().getMap();
         state = eWarp;
         QStringList args;
 
         int mode = comboMode->itemData(comboMode->currentIndex()).toInt();
-        if(mode > 0) {
+        if(mode > 0)
+        {
             args << "-order" << QString::number(mode);
         }
-        else if(mode == eThinPlate) {
+        else if(mode == eThinPlate)
+        {
             args << "-tps";
         }
 
-        if(map.is32BitRgb()){
+        if(map.is32BitRgb())
+        {
             args << "-r" << "cubic";
         }
         args << "-dstnodata" << "\"255\"";
@@ -755,7 +807,8 @@ void CCreateMapGeoTiff::slotFinished( int exitCode, QProcess::ExitStatus status)
         cmd.start("gdalwarp", args);
         return;
     }
-    if(state == eWarp) {
+    if(state == eWarp)
+    {
         state = eTile;
 
         QFile::remove(labelOutputFile->text());
@@ -809,7 +862,7 @@ void CCreateMapGeoTiff::slotClearAll()
     toolReload->setEnabled(false);
     labelStep2->setEnabled(false);
     treeWidget->setEnabled(false);
-    labelDoc2->setEnabled(false);
+    helpStep2->setEnabled(false);
     pushAddRef->setEnabled(false);
     pushLoadRef->setEnabled(false);
     pushSaveRef->setEnabled(false);
@@ -819,7 +872,7 @@ void CCreateMapGeoTiff::slotClearAll()
 
     labelStep3->setEnabled(false);
     textBrowser->setEnabled(false);
-    labelDoc3->setEnabled(false);
+    helpStep3->setEnabled(false);
 
     theMainWindow->getCanvas()->update();
 
