@@ -303,7 +303,8 @@ static QVector<QRgb>  qtColorTable(256);
 
 CCreateMapOSM::zoomlevel_t::~zoomlevel_t()
 {
-    if(dataset) {
+    if(dataset)
+    {
         qDebug() << "~zoomlevel_t()";
         dataset->FlushCache();
         delete dataset;
@@ -340,14 +341,16 @@ CCreateMapOSM::CCreateMapOSM(QWidget * parent)
     enableProxy = CResources::self().getHttpProxy(url,port);
 
     link = new QHttp(this);
-    if(enableProxy) {
+    if(enableProxy)
+    {
         link->setProxy(url,port);
     }
 
     connect(link,SIGNAL(requestFinished(int,bool)),this,SLOT(slotRequestFinished(int,bool)));
 
     // initialize color tables
-    for(int i=0; i<256; ++i) {
+    for(int i=0; i<256; ++i)
+    {
         gdalColorTable.SetColorEntry(i, &defaultColorTable[i]);
         qtColorTable[i] = qRgba(defaultColorTable[i].c1,defaultColorTable[i].c2,defaultColorTable[i].c3,defaultColorTable[i].c4);
     }
@@ -368,29 +371,35 @@ void CCreateMapOSM::slotCreate()
     if(!progress.isNull()) return;
 
     // sanity check
-    if(lineTopLeft->text().isEmpty()) {
+    if(lineTopLeft->text().isEmpty())
+    {
         QMessageBox::critical(this,tr("Information missing ..."), tr("The top left coordinate is missing"), QMessageBox::Abort, QMessageBox::Abort);
         return;
     }
-    if(lineBottomRight->text().isEmpty()) {
+    if(lineBottomRight->text().isEmpty())
+    {
         QMessageBox::critical(this,tr("Information missing ..."), tr("The bottom right coordinate is missing"), QMessageBox::Abort, QMessageBox::Abort);
         return;
     }
-    if(lineName->text().isEmpty()) {
+    if(lineName->text().isEmpty())
+    {
         QMessageBox::critical(this,tr("Information missing ..."), tr("The map name is missing."), QMessageBox::Abort, QMessageBox::Abort);
         return;
     }
-    if(lineComment->text().isEmpty()) {
+    if(lineComment->text().isEmpty())
+    {
         QMessageBox::critical(this,tr("Information missing ..."), tr("The comment is missing."), QMessageBox::Abort, QMessageBox::Abort);
         return;
     }
 
     // get top left and bottom right coordinate
     float lon1 = 0, lat1 = 0, lon2 = 0, lat2 = 0;
-    if(!GPS_Math_Str_To_Deg(lineTopLeft->text(), lon1, lat1)) {
+    if(!GPS_Math_Str_To_Deg(lineTopLeft->text(), lon1, lat1))
+    {
         return;
     }
-    if(!GPS_Math_Str_To_Deg(lineBottomRight->text(), lon2, lat2)) {
+    if(!GPS_Math_Str_To_Deg(lineBottomRight->text(), lon2, lat2))
+    {
         return;
     }
 
@@ -523,8 +532,10 @@ void CCreateMapOSM::addZoomLevel(int level, int zoom, double lon1, double lat1,
     z.band->SetColorTable(&gdalColorTable);
 
     // add tile definitions to list
-    for(y = y1; y <= y2; ++y) {
-        for(x = x1; x <= x2; ++x) {
+    for(y = y1; y <= y2; ++y)
+    {
+        for(x = x1; x <= x2; ++x)
+        {
             tile_t t;
             t.url.setPath(QString("/%1/%2/%3.png").arg(zoom).arg(x).arg(y));
             //             t.url.setPath(QString("/%1/%2/%3.png").arg(zoom).arg(x).arg(y));
@@ -541,13 +552,15 @@ void CCreateMapOSM::addZoomLevel(int level, int zoom, double lon1, double lat1,
 
 void CCreateMapOSM::getNextTile()
 {
-    if(progress && progress->wasCanceled()) {
+    if(progress && progress->wasCanceled())
+    {
         // TODO: unlink files!
         finishJob();
         return;
     }
 
-    if(tiles.isEmpty()) {
+    if(tiles.isEmpty())
+    {
         finishJob();
         QString fn = QString("%1.qmap").arg(QDir(labelPath->text()).filePath(lineName->text()));
         qDebug() << fn;
@@ -579,9 +592,11 @@ void CCreateMapOSM::slotRequestFinished(int id, bool error)
 {
     qDebug() << "slotRequestFinished(" <<  id << "," << error << ")";
 
-    if(error) {
+    if(error)
+    {
         QMessageBox::StandardButton res = QMessageBox::critical(this,tr("Failed to download tile!"), link->errorString(), QMessageBox::Retry|QMessageBox::Abort, QMessageBox::Retry);
-        if(res == QMessageBox::Retry) {
+        if(res == QMessageBox::Retry)
+        {
             getNextTile();
             return;
         }
@@ -591,7 +606,8 @@ void CCreateMapOSM::slotRequestFinished(int id, bool error)
 
     QImage img1,img2;
     img1.loadFromData(link->readAll());
-    if(img1.format() == QImage::Format_Invalid) {
+    if(img1.format() == QImage::Format_Invalid)
+    {
         // that:
         // link->setHost("tah.openstreetmap.org")
         // will cause a requestFinished() signal, too.
@@ -614,7 +630,8 @@ void CCreateMapOSM::slotRequestFinished(int id, bool error)
 void CCreateMapOSM::slotSelectPath()
 {
     QString path = QFileDialog::getExistingDirectory(this,tr("Select output path ..."), labelPath->text(), QFileDialog::DontUseNativeDialog);
-    if(!path.isEmpty()) {
+    if(!path.isEmpty())
+    {
         labelPath->setText(path);
     }
 }
