@@ -25,6 +25,7 @@
 #include "CWpt.h"
 #include "CTrackDB.h"
 #include "CTrack.h"
+#include "CResources.h"
 #include "CRouteDB.h"
 #include "CRoute.h"
 #include "CMapSelectionGarmin.h"
@@ -396,7 +397,6 @@ struct garmin_bmp_t
 #pragma pack(0)
 #endif
 
-
 /**
   @param progress the progress as integer from 0..100, if -1 no progress bar needed.
   @param ok if this pointer is 0 no ok button needed, if non zero set to 1 if ok button pressed
@@ -410,15 +410,18 @@ void GUICallback(int progress, int * ok, int * cancel, const char * title, const
     CDeviceGarmin * parent = static_cast<CDeviceGarmin *>(self);
     CDeviceGarmin::dlgdata_t& dd = parent->dlgData;
 
-    if(progress != -1) {
+    if(progress != -1)
+    {
         quint32 togo, hour, min, sec;
         QString message;
 
-        if(dd.dlgProgress == 0) {
+        if(dd.dlgProgress == 0)
+        {
             dd.canceled     = false;
             dd.dlgProgress  = new QProgressDialog(QString(title),0,0,100,theMainWindow, Qt::WindowStaysOnTopHint);
             dd.timeProgress.start();
-            if(cancel) {
+            if(cancel)
+            {
                 QPushButton * butCancel = new QPushButton(QObject::tr("Cancel"),dd.dlgProgress);
                 parent->connect(butCancel, SIGNAL(clicked()), parent, SLOT(slotCancel()));
                 dd.dlgProgress->setCancelButton(butCancel);
@@ -439,33 +442,40 @@ void GUICallback(int progress, int * ok, int * cancel, const char * title, const
         dd.dlgProgress->setLabelText(QString(msg) + message);
         dd.dlgProgress->setValue(progress);
 
-        if(progress == 100 && dd.dlgProgress) {
+        if(progress == 100 && dd.dlgProgress)
+        {
             delete dd.dlgProgress;
             dd.dlgProgress = 0;
         }
 
-        if(cancel) {
+        if(cancel)
+        {
             *cancel = dd.canceled;
         }
 
         qApp->processEvents();
 
     }
-    else {
-        if(ok && cancel) {
+    else
+    {
+        if(ok && cancel)
+        {
             QMessageBox::StandardButtons res = QMessageBox::question(theMainWindow,QString(title),QString(msg),QMessageBox::Ok|QMessageBox::Cancel,QMessageBox::Cancel);
             *ok     = res == QMessageBox::Ok;
             *cancel = res == QMessageBox::Cancel;
         }
-        else if(ok && !cancel) {
+        else if(ok && !cancel)
+        {
             QMessageBox::question(theMainWindow,QString(title),QString(msg),QMessageBox::Ok,QMessageBox::Ok);
             *ok     = true;
         }
-        else if(!ok && cancel) {
+        else if(!ok && cancel)
+        {
             QMessageBox::question(theMainWindow,QString(title),QString(msg),QMessageBox::Cancel,QMessageBox::Cancel);
             *cancel     = true;
         }
-        else if(!ok && !cancel) {
+        else if(!ok && !cancel)
+        {
             //kiozen - that doesn't work nicely
             //             QMessageBox * dlg = new QMessageBox(&parent->main);
             //             dlg->setWindowTitle(QString(title));
@@ -504,23 +514,54 @@ Garmin::IDevice * CDeviceGarmin::getDevice()
     Garmin::IDevice * (*func)(const char*) = 0;
     Garmin::IDevice * dev = 0;
 
+#if defined(Q_WS_MAC)
+    // MacOS X: plug-ins are stored in the bundle folder
+    QString libname     = QString("%1/lib%2" XSTR(SHARED_LIB_EXT))
+        .arg(QCoreApplication::applicationDirPath().replace(QRegExp("MacOS$"), "Resources/Drivers"))
+        .arg(devkey);
+#else
     QString libname     = QString("%1/lib%2" XSTR(SHARED_LIB_EXT)).arg(XSTR(PLUGINDIR)).arg(devkey);
+#endif
     QString funcname    = QString("init%1").arg(devkey);
 
-    func = (Garmin::IDevice * (*)(const char*))QLibrary::resolve(libname,funcname.toAscii());
+    QLibrary lib;
+    lib.setFileName(libname);
+    bool lib_loaded = lib.load();
+    if (lib_loaded)
+    {
+        func = (Garmin::IDevice * (*)(const char*))lib.resolve(funcname.toAscii());
+    }
 
-    if(func == 0) {
-        QMessageBox::warning(0,tr("Error ..."),tr("Failed to load driver."),QMessageBox::Ok,QMessageBox::NoButton);
+    if(!lib_loaded || func == 0)
+    {
+        QMessageBox warn;
+        warn.setIcon(QMessageBox::Warning);
+        warn.setWindowTitle(tr("Error ..."));
+        warn.setText(tr("Failed to load driver."));
+        warn.setDetailedText(lib.errorString());
+        warn.setStandardButtons(QMessageBox::Ok);
+        warn.exec();
         return 0;
     }
 
     dev = func(INTERFACE_VERSION);
-    if(dev == 0) {
-        QMessageBox::warning(0,tr("Error ..."),tr("Driver version mismatch."),QMessageBox::Ok,QMessageBox::NoButton);
+    if(dev == 0)
+    {
+        QMessageBox warn;
+        warn.setIcon(QMessageBox::Warning);
+        warn.setWindowTitle(tr("Error ..."));
+        warn.setText(tr("Driver version mismatch."));
+        QString detail = QString(
+            tr("The version of your driver plugin \"%1\" does not match the version QLandkarteGT expects (\"%2\").")
+            ).arg(libname).arg(INTERFACE_VERSION);
+        warn.setDetailedText(detail);
+        warn.setStandardButtons(QMessageBox::Ok);
+        warn.exec();
         func = 0;
     }
 
-    if(dev) {
+    if(dev)
+    {
         dev->setPort(port.toLatin1());
         dev->setGuiCallback(GUICallback,this);
     }
@@ -545,57 +586,62 @@ void CDeviceGarmin::slotTimeout()
     {
         dev->getRealTimePos(pvt);
     }
-    catch(int /*e*/) {
-    timer->stop();
-    log.fix = CLiveLog::eOff;
+    catch(int e)
+    {
+        timer->stop();
+        log.fix = CLiveLog::eOff;
+        emit sigLiveLog(log);
+
+        QMessageBox::warning(0,tr("Device Link Error"),dev->getLastError().c_str(),QMessageBox::Ok,QMessageBox::NoButton);
+        return;
+    }
+
+    log.fix = pvt.fix == 3 || pvt.fix == 5 ? CLiveLog::e3DFix : pvt.fix == 2 || pvt.fix == 4 ? CLiveLog::e2DFix : CLiveLog::eNoFix;
+    if(log.fix != CLiveLog::eNoFix)
+    {
+        log.lon = pvt.lon;
+        log.lat = pvt.lat;
+        log.ele = pvt.alt + pvt.msl_hght;
+
+        QDateTime t(QDate(1989,12,31), QTime(0,0), Qt::UTC);
+        t = t.addDays(pvt.wn_days).addSecs((int)(pvt.tow + 0.5)).addSecs(-pvt.leap_scnds);
+        log.timestamp = t.toLocalTime().toTime_t();
+
+        // multiply by 100 to avoid leaving the float range.
+        float heading = fabsf((100.0 * pvt.east) / (100.0 * pvt.north));
+        heading = atanf(heading) / (TWOPI) * 360.0;
+        if( (pvt.north > 0.0) & (pvt.east > 0.0) )
+        {
+            // 1st quadrant
+            heading = heading;
+        }
+        else if( (pvt.north > 0.0) & (pvt.east < 0.0) )
+        {
+            // 2nd quadrant
+            heading = 360.0 - heading;
+        }
+        else if( (pvt.north < 0.0) & (pvt.east < 0.0) )
+        {
+            // 3rd quadrant
+            heading = 180.0 + heading;
+        }
+        else if( (pvt.north < 0.0) & (pvt.east > 0.0) )
+        {
+            // 4th quadrant
+            heading = 180.0 - heading;
+        }
+        else
+        {
+            heading = std::numeric_limits<float>::quiet_NaN();
+        }
+
+        log.heading     = heading;
+        log.velocity    = sqrtf( pvt.north * pvt.north + pvt.east * pvt.east );
+        log.error_horz  = pvt.eph;
+        log.error_vert  = pvt.epv;
+    }
+
     emit sigLiveLog(log);
-
-    QMessageBox::warning(0,tr("Device Link Error"),dev->getLastError().c_str(),QMessageBox::Ok,QMessageBox::NoButton);
-    return;
-}
-
-
-log.fix = pvt.fix == 3 || pvt.fix == 5 ? CLiveLog::e3DFix : pvt.fix == 2 || pvt.fix == 4 ? CLiveLog::e2DFix : CLiveLog::eNoFix;
-if(log.fix != CLiveLog::eNoFix) {
-    log.lon = pvt.lon;
-    log.lat = pvt.lat;
-    log.ele = pvt.alt + pvt.msl_hght;
-
-    QDateTime t(QDate(1989,12,31), QTime(0,0), Qt::UTC);
-    t = t.addDays(pvt.wn_days).addSecs((int)(pvt.tow + 0.5)).addSecs(-pvt.leap_scnds);
-    log.timestamp = t.toLocalTime().toTime_t();
-
-    // multiply by 100 to avoid leaving the float range.
-    float heading = fabsf((100.0 * pvt.east) / (100.0 * pvt.north));
-    heading = atanf(heading) / (TWOPI) * 360.0;
-    if( (pvt.north > 0.0) & (pvt.east > 0.0) ) {
-        // 1st quadrant
-        heading = heading;
-    }
-    else if( (pvt.north > 0.0) & (pvt.east < 0.0) ) {
-        // 2nd quadrant
-        heading = 360.0 - heading;
-    }
-    else if( (pvt.north < 0.0) & (pvt.east < 0.0) ) {
-        // 3rd quadrant
-        heading = 180.0 + heading;
-    }
-    else if( (pvt.north < 0.0) & (pvt.east > 0.0) ) {
-        // 4th quadrant
-        heading = 180.0 - heading;
-    }
-    else {
-        heading = std::numeric_limits<float>::quiet_NaN();
-    }
-
-    log.heading     = heading;
-    log.velocity    = sqrtf( pvt.north * pvt.north + pvt.east * pvt.east );
-    log.error_horz  = pvt.eph;
-    log.error_vert  = pvt.epv;
-}
-
-
-emit sigLiveLog(log);
 }
 
 
@@ -606,14 +652,18 @@ void CDeviceGarmin::uploadWpts(const QList<CWpt*>& wpts)
     if(dev == 0) return;
 
     std::list<Garmin::Wpt_t> garwpts;
+    QTextCodec *codec = QTextCodec::codecForName(CResources::self().charset().toAscii());
 
     QMap<QString,CWpt*>::iterator wpt = CWptDB::self().begin();
-    while(wpt != CWptDB::self().end()) {
+    while(wpt != CWptDB::self().end())
+    {
         Garmin::Wpt_t garwpt;
 
         garmin_icon_t * icon = GarminIcons;
-        while(icon->name != 0) {
-            if((*wpt)->icon == icon->name) {
+        while(icon->name != 0)
+        {
+            if((*wpt)->icon == icon->name)
+            {
                 garwpt.smbl = icon->id;
                 break;
             }
@@ -624,72 +674,92 @@ void CDeviceGarmin::uploadWpts(const QList<CWpt*>& wpts)
         garwpt.lon      = (*wpt)->lon;
         garwpt.alt      = (*wpt)->ele;
         garwpt.dist     = (*wpt)->prx;
-        garwpt.ident    = (*wpt)->name.toLocal8Bit().data();
-        garwpt.comment  = (*wpt)->comment.toLocal8Bit().data();
+        garwpt.ident    = codec->fromUnicode((*wpt)->name).data();
+        garwpt.comment  = codec->fromUnicode((*wpt)->comment).data();
 
         garwpts.push_back(garwpt);
 
         ++wpt;
     }
 
+    QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
     try
     {
         dev->uploadWaypoints(garwpts);
-        QSound::play(":/sounds/xfer-done.wav");
+        if (CResources::self().playSound())
+        {
+            QSound::play(":/sounds/xfer-done.wav");
+        }
+
+        QApplication::restoreOverrideCursor();
+    }
+    catch(int e)
+    {
+        QMessageBox::warning(0,tr("Device Link Error"),dev->getLastError().c_str(),QMessageBox::Ok,QMessageBox::NoButton);
+        QApplication::restoreOverrideCursor();
+        return;
     }
-    catch(int /*e*/) {
-    QMessageBox::warning(0,tr("Device Link Error"),dev->getLastError().c_str(),QMessageBox::Ok,QMessageBox::NoButton);
-    return;
-}
-
 
 }
 
+
 void CDeviceGarmin::downloadWpts(QList<CWpt*>& wpts)
 {
     qDebug() << "CDeviceGarmin::downloadWpts()";
     Garmin::IDevice * dev = getDevice();
     if(dev == 0) return;
 
+    QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
     std::list<Garmin::Wpt_t> garwpts;
     try
     {
         dev->downloadWaypoints(garwpts);
-        QSound::play(":/sounds/xfer-done.wav");
-    }
-    catch(int /*e*/) {
-    QMessageBox::warning(0,tr("Device Link Error"),dev->getLastError().c_str(),QMessageBox::Ok,QMessageBox::NoButton);
-    return;
-}
-
-
-std::list<Garmin::Wpt_t>::const_iterator garwpt = garwpts.begin();
-while(garwpt != garwpts.end()) {
-    CWpt * wpt = new CWpt(&CWptDB::self());
-
-    wpt->name       = garwpt->ident.c_str();
-    wpt->comment    = garwpt->comment.c_str();
-    wpt->lon        = garwpt->lon;
-    wpt->lat        = garwpt->lat;
-    wpt->ele        = garwpt->alt;
-    wpt->prx        = garwpt->dist;
-
-    garmin_icon_t * icon = GarminIcons;
-    while(icon->name != 0) {
-        if(garwpt->smbl == icon->id) {
-            wpt->icon = icon->name;
-            break;
+        if (CResources::self().playSound())
+        {
+            QSound::play(":/sounds/xfer-done.wav");
         }
-        ++icon;
+
+        QApplication::restoreOverrideCursor();
+    }
+    catch(int e)
+    {
+        QMessageBox::warning(0,tr("Device Link Error"),dev->getLastError().c_str(),QMessageBox::Ok,QMessageBox::NoButton);
+        QApplication::restoreOverrideCursor();
+        return;
     }
 
-    wpts << wpt;
-    ++garwpt;
-}
+    QTextCodec *codec = QTextCodec::codecForName(CResources::self().charset().toAscii());
 
+    std::list<Garmin::Wpt_t>::const_iterator garwpt = garwpts.begin();
+    while(garwpt != garwpts.end())
+    {
+        CWpt * wpt = new CWpt(&CWptDB::self());
+
+        wpt->name       = codec->toUnicode(garwpt->ident.c_str());
+        wpt->comment    = codec->toUnicode(garwpt->comment.c_str());
+        wpt->lon        = garwpt->lon;
+        wpt->lat        = garwpt->lat;
+        wpt->ele        = garwpt->alt;
+        wpt->prx        = garwpt->dist;
+
+        garmin_icon_t * icon = GarminIcons;
+        while(icon->name != 0)
+        {
+            if(garwpt->smbl == icon->id)
+            {
+                wpt->icon = icon->name;
+                break;
+            }
+            ++icon;
+        }
+
+        wpts << wpt;
+        ++garwpt;
+    }
 
 }
 
+
 void CDeviceGarmin::uploadTracks(const QList<CTrack*>& trks)
 {
     qDebug() << "CDeviceGarmin::uploadTracks()";
@@ -698,17 +768,20 @@ void CDeviceGarmin::uploadTracks(const QList<CTrack*>& trks)
     if(dev == 0) return;
 
     std::list<Garmin::Track_t> gartrks;
+    QTextCodec *codec = QTextCodec::codecForName(CResources::self().charset().toAscii());
 
     QList<CTrack*>::const_iterator trk = trks.begin();
-    while(trk != trks.end()) {
+    while(trk != trks.end())
+    {
         Garmin::Track_t gartrk;
 
-        gartrk.ident = (*trk)->getName().toLocal8Bit().data();
+        gartrk.ident = codec->fromUnicode((*trk)->getName()).data();
         gartrk.color = (*trk)->getColorIdx();
 
         const QList<CTrack::pt_t>& trkpts           = (*trk)->getTrackPoints();
         QList<CTrack::pt_t>::const_iterator trkpt   =  trkpts.begin();
-        while(trkpt != trkpts.end()) {
+        while(trkpt != trkpts.end())
+        {
             Garmin::TrkPt_t gartrkpt;
 
             QDateTime t = QDateTime::fromTime_t(trkpt->timestamp);
@@ -727,46 +800,65 @@ void CDeviceGarmin::uploadTracks(const QList<CTrack*>& trks)
         ++trk;
     }
 
+    QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
     try
     {
         dev->uploadTracks(gartrks);
-        QSound::play(":/sounds/xfer-done.wav");
+        if (CResources::self().playSound())
+        {
+            QSound::play(":/sounds/xfer-done.wav");
+        }
+
+        QApplication::restoreOverrideCursor();
+    }
+    catch(int e)
+    {
+        QMessageBox::warning(0,tr("Device Link Error"),dev->getLastError().c_str(),QMessageBox::Ok,QMessageBox::NoButton);
+        QApplication::restoreOverrideCursor();
+        return;
     }
-    catch(int /*e*/) {
-    QMessageBox::warning(0,tr("Device Link Error"),dev->getLastError().c_str(),QMessageBox::Ok,QMessageBox::NoButton);
-    return;
-}
-
 
 }
 
+
 void CDeviceGarmin::downloadTracks(QList<CTrack*>& trks)
 {
     qDebug() << "CDeviceGarmin::downloadTracks()";
     Garmin::IDevice * dev = getDevice();
     if(dev == 0) return;
 
+    QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
     std::list<Garmin::Track_t> gartrks;
     try
     {
         dev->downloadTracks(gartrks);
-        QSound::play(":/sounds/xfer-done.wav");
+        if (CResources::self().playSound())
+        {
+            QSound::play(":/sounds/xfer-done.wav");
+        }
+
+        QApplication::restoreOverrideCursor();
     }
-    catch(int /*e*/) {
+    catch(int e)
+    {
         QMessageBox::warning(0,tr("Device Link Error"),dev->getLastError().c_str(),QMessageBox::Ok,QMessageBox::NoButton);
+        QApplication::restoreOverrideCursor();
         return;
     }
 
+    QTextCodec *codec = QTextCodec::codecForName(CResources::self().charset().toAscii());
     std::list<Garmin::Track_t>::const_iterator gartrk = gartrks.begin();
-    while(gartrk != gartrks.end()) {
+    while(gartrk != gartrks.end())
+    {
 
         CTrack * trk = new CTrack(&CTrackDB::self());
 
-        trk->setName(gartrk->ident.c_str());
+        trk->setName(codec->toUnicode(gartrk->ident.c_str()));
         trk->setColor(gartrk->color);
 
         std::vector<Garmin::TrkPt_t>::const_iterator gartrkpt = gartrk->track.begin();
-        while(gartrkpt != gartrk->track.end()) {
+        while(gartrkpt != gartrk->track.end())
+        {
             QDateTime t = QDateTime::fromTime_t(gartrkpt->time);
             t = t.addYears(20).addDays(-1);
 
@@ -780,14 +872,20 @@ void CDeviceGarmin::downloadTracks(QList<CTrack*>& trks)
             ++gartrkpt;
         }
 
-        if(trk->getTrackPoints().count() > 0) {
+        if(trk->getTrackPoints().count() > 0)
+        {
             trks << trk;
         }
+        else
+        {
+            delete trk;
+        }
         ++gartrk;
     }
 
 }
 
+
 void CDeviceGarmin::downloadScreenshot(QImage& image)
 {
     qDebug() << "CDeviceGarmin::downloadScreenshot()";
@@ -799,17 +897,26 @@ void CDeviceGarmin::downloadScreenshot(QImage& image)
     int     width   = 0;
     int     height  = 0;
 
+    QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
     try
     {
         dev->screenshot(clrtbl, data, width, height);
-        QSound::play(":/sounds/xfer-done.wav");
+        if (CResources::self().playSound())
+        {
+            QSound::play(":/sounds/xfer-done.wav");
+        }
+
+        QApplication::restoreOverrideCursor();
     }
-    catch(int /*e*/) {
+    catch(int e)
+    {
         QMessageBox::warning(0,tr("Device Link Error"),dev->getLastError().c_str(),QMessageBox::Ok,QMessageBox::NoButton);
+        QApplication::restoreOverrideCursor();
         return;
     }
 
-    if(data != 0 && clrtbl != 0) {
+    if(data != 0 && clrtbl != 0)
+    {
         /* Hack hack hack - add two dummy bytes at the beginning of the array which are
          * removed below, and let the bmp record start at offs 2.  This shifts all 4-byte
          * data in the record to adresses which are a multiple of 4. */
@@ -836,8 +943,10 @@ void CDeviceGarmin::downloadScreenshot(QImage& image)
         image.loadFromData((const uchar *)pBmp, sizeof(garmin_bmp_t) + width * height);
 
     }
+
 }
 
+
 void CDeviceGarmin::uploadRoutes(const QList<CRoute*>& rtes)
 {
     Garmin::IDevice * dev = getDevice();
@@ -846,14 +955,19 @@ void CDeviceGarmin::uploadRoutes(const QList<CRoute*>& rtes)
     std::list<Garmin::Route_t> garrtes;
     int id = 0;
 
+    QTextCodec *codec = QTextCodec::codecForName(CResources::self().charset().toAscii());
+
     QList<CRoute*>::const_iterator rte = rtes.begin();
-    while(rte != rtes.end()) {
+    while(rte != rtes.end())
+    {
         Garmin::Route_t garrte;
 
         uint16_t smbl = 8198;
         garmin_icon_t * icon = GarminIcons;
-        while(icon->name != 0) {
-            if((*rte)->getIconName() == icon->name) {
+        while(icon->name != 0)
+        {
+            if((*rte)->getIconName() == icon->name)
+            {
                 smbl = icon->id;
                 break;
             }
@@ -861,18 +975,19 @@ void CDeviceGarmin::uploadRoutes(const QList<CRoute*>& rtes)
         }
 
         QString name = (*rte)->getName();
-        garrte.ident = name.toLocal8Bit().data();
+        garrte.ident = codec->fromUnicode(name).data();
 
         unsigned cnt = 0;
         const QList<XY>& rtepts         = (*rte)->getRoutePoints();
         QList<XY>::const_iterator rtept =  rtepts.begin();
-        while(rtept != rtepts.end()) {
+        while(rtept != rtepts.end())
+        {
             Garmin::RtePt_t garrtept;
 
             garrtept.lon            = rtept->u;
             garrtept.lat            = rtept->v;
             garrtept.Wpt_t::ident   = QString("%1.%2").arg(id).arg(++cnt,3,10,QChar('0')).toAscii().data();
-            garrtept.Wpt_t::comment = name.toAscii().data();
+            garrtept.Wpt_t::comment = codec->fromUnicode(name).data();
             garrtept.Wpt_t::smbl    = smbl;
 
             garrte.route.push_back(garrtept);
@@ -883,22 +998,80 @@ void CDeviceGarmin::uploadRoutes(const QList<CRoute*>& rtes)
         ++rte; ++id;
     }
 
+    QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
     try
     {
         dev->uploadRoutes(garrtes);
-        QSound::play(":/sounds/xfer-done.wav");
+        if (CResources::self().playSound())
+        {
+            QSound::play(":/sounds/xfer-done.wav");
+        }
+
+        QApplication::restoreOverrideCursor();
+    }
+    catch(int e)
+    {
+        QMessageBox::warning(0,tr("Device Link Error"),dev->getLastError().c_str(),QMessageBox::Ok,QMessageBox::NoButton);
+        QApplication::restoreOverrideCursor();
+        return;
     }
-    catch(int /*e*/) {
-    QMessageBox::warning(0,tr("Device Link Error"),dev->getLastError().c_str(),QMessageBox::Ok,QMessageBox::NoButton);
-    return;
-}
-
 
 }
 
+
 void CDeviceGarmin::downloadRoutes(QList<CRoute*>& rtes)
 {
-    QMessageBox::information(0,tr("Error..."), tr("Garmin: Download routes is not implemented."),QMessageBox::Abort,QMessageBox::Abort);
+    qDebug() << "CDeviceGarmin::downloadRoutes()";
+    Garmin::IDevice * dev = getDevice();
+    if(dev == 0) return;
+
+    QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
+    std::list<Garmin::Route_t> garrtes;
+    try
+    {
+        dev->downloadRoutes(garrtes);
+        if (CResources::self().playSound())
+        {
+            QSound::play(":/sounds/xfer-done.wav");
+        }
+
+        QApplication::restoreOverrideCursor();
+    }
+    catch(int e)
+    {
+        QMessageBox::warning(0,tr("Device Link Error"),dev->getLastError().c_str(),QMessageBox::Ok,QMessageBox::NoButton);
+        QApplication::restoreOverrideCursor();
+        return;
+    }
+
+    QTextCodec *codec = QTextCodec::codecForName(CResources::self().charset().toAscii());
+
+    std::list<Garmin::Route_t>::const_iterator garrte = garrtes.begin();
+    while(garrte != garrtes.end())
+    {
+
+        CRoute * rte = new CRoute(&CRouteDB::self());
+
+        rte->setName(codec->toUnicode(garrte->ident.c_str()));
+
+        std::vector<Garmin::RtePt_t>::const_iterator garrtept = garrte->route.begin();
+        while(garrtept != garrte->route.end())
+        {
+            rte->addPosition(garrtept->lon, garrtept->lat);
+            ++garrtept;
+        }
+
+        if(rte->getRoutePoints().count() > 0)
+        {
+            rtes << rte;
+        }
+        else
+        {
+            delete rte;
+        }
+        ++garrte;
+    }
+
 }
 
 
@@ -909,8 +1082,10 @@ void CDeviceGarmin::uploadMap(const QList<IMapSelection*>& mss)
 
     QList<IMapSelection*>::const_iterator ms = mss.begin();
 
-    while(ms != mss.end()) {
-        if((*ms)->type == IMapSelection::eGarmin) {
+    while(ms != mss.end())
+    {
+        if((*ms)->type == IMapSelection::eGarmin)
+        {
             break;
         }
         ++ms;
@@ -923,15 +1098,18 @@ void CDeviceGarmin::uploadMap(const QList<IMapSelection*>& mss)
 
     CGarminExport dlg(0);
     dlg.exportToFile(*gms, tmpfile.fileName());
-    if(dlg.hadErrors()) {
+    if(dlg.hadErrors())
+    {
         QMessageBox::warning(0,tr("Error..."), tr("Failed to create image file."),QMessageBox::Abort,QMessageBox::Abort);
         return;
     }
 
     QStringList keys;
     QMap<QString, CMapSelectionGarmin::map_t>::const_iterator map = gms->maps.begin();
-    while(map != gms->maps.end()) {
-        if(!map->unlockKey.isEmpty()) {
+    while(map != gms->maps.end())
+    {
+        if(!map->unlockKey.isEmpty())
+        {
             keys << map->unlockKey;
         }
         ++map;
@@ -940,19 +1118,26 @@ void CDeviceGarmin::uploadMap(const QList<IMapSelection*>& mss)
     QFileInfo fi(tmpfile.fileName());
 
     qDebug() << fi.size();
+    QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
     try
     {
         dev->uploadMap(tmpfile.fileName().toLocal8Bit(), (quint32)fi.size() , keys.isEmpty() ? 0 : keys[0].toAscii().data());
-        QSound::play(":/sounds/xfer-done.wav");
+        if (CResources::self().playSound())
+        {
+            QSound::play(":/sounds/xfer-done.wav");
+        }
+        QApplication::restoreOverrideCursor();
+    }
+    catch(int e)
+    {
+        QMessageBox::warning(0,tr("Device Link Error"),dev->getLastError().c_str(),QMessageBox::Ok,QMessageBox::NoButton);
+        QApplication::restoreOverrideCursor();
+        return;
     }
-    catch(int /*e*/) {
-    QMessageBox::warning(0,tr("Device Link Error"),dev->getLastError().c_str(),QMessageBox::Ok,QMessageBox::NoButton);
-    return;
-}
-
 
 }
 
+
 void CDeviceGarmin::setLiveLog(bool on)
 {
     Garmin::IDevice * dev = getDevice();
@@ -962,7 +1147,8 @@ void CDeviceGarmin::setLiveLog(bool on)
     {
         dev->setRealTimeMode(on);
     }
-    catch(int /*e*/) {
+    catch(int e)
+    {
         timer->stop();
         log.fix = CLiveLog::eOff;
         emit sigLiveLog(log);
@@ -971,11 +1157,13 @@ void CDeviceGarmin::setLiveLog(bool on)
         return;
     }
 
-
-    if(on && !timer->isActive()) {
+    if(on && !timer->isActive())
+    {
         timer->start(1000);
     }
-    else {
+
+    else
+    {
         timer->stop();
         log.fix = CLiveLog::eOff;
         emit sigLiveLog(log);
@@ -983,9 +1171,8 @@ void CDeviceGarmin::setLiveLog(bool on)
 
 }
 
+
 bool CDeviceGarmin::liveLog()
 {
     return timer->isActive();
 }
-
-
