@@ -39,7 +39,8 @@ void CGarminStrTblUtf8::get(QFile& file, quint32 offset, type_e t, QStringList&
 
     if(offset == 0xFFFFFFFF) return;
 
-    if(offset > (quint32)sizeLBL1) {
+    if(offset > (quint32)sizeLBL1)
+    {
         //qWarning() << "Index into string table to large" << hex << offset << dataLBL.size() << hdrLbl->addr_shift << hdrNet->net1_addr_shift;
         return;
     }
@@ -49,27 +50,33 @@ void CGarminStrTblUtf8::get(QFile& file, quint32 offset, type_e t, QStringList&
     char * lbl = data.data();
 
     char * pBuffer = buffer; *pBuffer = 0;
-    while(*lbl != 0) {
-        if((unsigned)*lbl >= 0x1B && (unsigned)*lbl <= 0x1F) {
+    while(*lbl != 0)
+    {
+        if((unsigned)*lbl >= 0x1B && (unsigned)*lbl <= 0x1F)
+        {
             *pBuffer = 0;
-            if(strlen(buffer)) {
+            if(strlen(buffer))
+            {
                 labels << codec->toUnicode(buffer);
                 pBuffer = buffer; *pBuffer = 0;
             }
             ++lbl;
             continue;
         }
-        else if((unsigned)*lbl < 0x07) {
+        else if((unsigned)*lbl < 0x07)
+        {
             ++lbl;
             continue;
         }
-        else {
+        else
+        {
             *pBuffer++ = *lbl++;
         }
     }
 
     *pBuffer = 0;
-    if(strlen(buffer)) {
+    if(strlen(buffer))
+    {
         //         qDebug() << QString(buffer);
         labels << codec->toUnicode(buffer);
     }
