@@ -1,5 +1,5 @@
 /**********************************************************************************************
-    Copyright (C) 2008 Oliver Eichler oliver.eichler@gmx.de
+    Copyright (C) 2008-2009 Oliver Eichler oliver.eichler@gmx.de
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -41,6 +41,8 @@
 #include "IDevice.h"
 #include "CDlgScreenshot.h"
 #include "CUndoStack.h"
+#include "WptIcons.h"
+#include "CAppOpts.h"
 
 #include <QtGui>
 #ifdef WIN32
@@ -58,6 +60,9 @@ CMainWindow::CMainWindow()
     setObjectName("MainWidget");
     setWindowTitle("QLandkarte GT");
     setWindowIcon(QIcon(":/icons/iconGlobe16x16.png"));
+    setAcceptDrops(true);
+
+    initWptIcons();
 
     resources = new CResources(this);
 
@@ -107,7 +112,6 @@ CMainWindow::CMainWindow()
     actionGroupProvider->addAction(CMenus::MainMenu, "aUploadAll");
     actionGroupProvider->addAction(CMenus::MainMenu, "aDownloadAll");
 
-    actionGroupProvider->addAction(CMenus::MapMenu, "aSwitchToMain");
     actionGroupProvider->addAction(CMenus::MapMenu, "aSwitchToMain");
     actionGroupProvider->addAction(CMenus::MapMenu, "aMoveArea");
     actionGroupProvider->addAction(CMenus::MapMenu, "aZoomArea");
@@ -120,6 +124,9 @@ CMainWindow::CMainWindow()
     actionGroupProvider->addAction(CMenus::MapMenu, "aSwitchToMap3D");
 #endif
     actionGroupProvider->addAction(CMenus::MapMenu, "aUploadMap");
+
+    //     actionGroupProvider->addAction(CMenus::MapMenu, "aZoomIn");
+    //     actionGroupProvider->addAction(CMenus::MapMenu, "aZoomOut");
     //    fsMap[10] = func_key_state_t(0,tr("-"),0,tr(""));
 
 #ifdef PLOT_3D
@@ -128,6 +135,7 @@ CMainWindow::CMainWindow()
     actionGroupProvider->addAction(CMenus::Map3DMenu, "aMap3DZoomPlus");
     actionGroupProvider->addAction(CMenus::Map3DMenu, "aMap3DZoomMinus");
     actionGroupProvider->addAction(CMenus::Map3DMenu, "aMap3DLighting");
+    //actionGroupProvider->addAction(CMenus::Map3DMenu, "aMap3DTrackmode");
     //    fsMap3D[5] = func_key_state_t(0,tr("-"),0,tr(""));
     //    fsMap3D[6] = func_key_state_t(0,tr("-"),0,tr(""));
     //    fsMap3D[7] = func_key_state_t(0,tr("-"),0,tr(""));
@@ -198,7 +206,7 @@ CMainWindow::CMainWindow()
     actionGroupProvider->addAction(CMenus::MainMoreMenu, "aCenterMap");
     //    fsMainMore[4] = func_key_state_t(0,tr("-"),0,tr(""));
     actionGroupProvider->addAction(CMenus::MainMoreMenu, "aDiary");
-    actionGroupProvider->addAction(CMenus::MainMoreMenu, "aColorPicker");
+    //     actionGroupProvider->addAction(CMenus::MainMoreMenu, "aColorPicker");
     actionGroupProvider->addAction(CMenus::MainMoreMenu, "aWorldBasemap");
     //    fsMainMore[8] = func_key_state_t(0,tr("-"),0,tr(""));
     //    fsMainMore[9] = func_key_state_t(0,tr("-"),0,tr(""));
@@ -278,7 +286,8 @@ CMainWindow::CMainWindow()
 
     // restore last session position and size of mainWidget
     {
-        if ( cfg.contains("mainWidget/geometry")) {
+        if ( cfg.contains("mainWidget/geometry"))
+        {
             QRect r = cfg.value("mainWidget/geometry").toRect();
             //qDebug() << r << QDesktopWidget().screenGeometry();
             if (r.isValid() && QDesktopWidget().screenGeometry().intersects(r))
@@ -299,10 +308,12 @@ CMainWindow::CMainWindow()
     sizes[2] = (int)(mainSplitter->height() * 0.4);
     leftSplitter->setSizes(sizes);
 
-    if( cfg.contains("mainWidget/mainSplitter") ) {
+    if( cfg.contains("mainWidget/mainSplitter") )
+    {
         mainSplitter->restoreState(cfg.value("mainWidget/mainSplitter",mainSplitter->saveState()).toByteArray());
     }
-    if( cfg.contains("mainWidget/leftSplitter") ) {
+    if( cfg.contains("mainWidget/leftSplitter") )
+    {
         leftSplitter->restoreState(cfg.value("mainWidget/leftSplitter",leftSplitter->saveState()).toByteArray());
     }
 
@@ -324,15 +335,16 @@ CMainWindow::CMainWindow()
     canvas->setMouseMode(CCanvas::eMouseMoveArea);
     megaMenu->switchByKeyWord("Main");
 
-    snRead = new QSocketNotifier(0, QSocketNotifier::Read, this);
-    connect(snRead, SIGNAL(activated(int)), this, SLOT(slotReloadArgs()));
+    if (qlOpts->monitor != -1)
+    {
+        snRead = new QSocketNotifier(qlOpts->monitor, QSocketNotifier::Read, this);
+        connect(snRead, SIGNAL(activated(int)), this, SLOT(slotReloadArgs()));
+    }
 
+    mostRecent = cfg.value("geodata/mostRecent",QStringList()).toStringList();
 
-
-
-    QStringList args = QCoreApplication::arguments();
-    args.removeFirst();
-    foreach(QString arg, args) {
+    foreach(QString arg, qlOpts->arguments)
+    {
         loadData(arg, QString());
     }
 
@@ -340,6 +352,7 @@ CMainWindow::CMainWindow()
     connect(actionGroupProvider, SIGNAL(stateChanged()), this, SLOT(switchState()));
 
     megaMenu->slotSplitterMoved(leftSplitter->sizes()[0], 1);
+
 }
 
 
@@ -348,28 +361,29 @@ void CMainWindow::slotReloadArgs()
     char c;
     int i;
 #ifdef WIN32
-    i=_read(0, &c, 1);		// read char
+                                 // read char
+    i = _read(qlOpts->monitor, &c, 1);
 #else
-	i=read(0, &c, 1);		// read char
+                                 // read char
+    i = read(qlOpts->monitor, &c, 1);
 #endif
 
-    if(i != 1){
+    if(i != 1)
+    {
         delete snRead;
         return;
     }
 
-//    CMapDB::self().clear();
+    //    CMapDB::self().clear();
     CWptDB::self().clear();
     CTrackDB::self().clear();
-//    CRouteDB::self().clear();
-//    CDiaryDB::self().clear();
-//    COverlayDB::self().clear();
+    //    CRouteDB::self().clear();
+    //    CDiaryDB::self().clear();
+    //    COverlayDB::self().clear();
 
-    QStringList args = QCoreApplication::arguments();
-    args.removeFirst();
-    foreach(QString arg, args)
+    foreach(QString arg, qlOpts->arguments)
     {
-      loadData(arg, QString());
+        loadData(arg, QString());
     }
 }
 
@@ -381,17 +395,51 @@ CMainWindow::~CMainWindow()
     cfg.setValue("mainWidget/leftSplitter",leftSplitter->saveState());
     cfg.setValue("path/data",pathData);
     cfg.setValue("mainWidget/geometry", geometry());
-
+    cfg.setValue("geodata/mostRecent", mostRecent);
     canvas = 0;
 }
 
 
+void CMainWindow::dragEnterEvent(QDragEnterEvent *event)
+{
+    if(event->mimeData()->hasUrls())
+    {
+        QList<QUrl> urls = event->mimeData()->urls();
+        QFileInfo fi(urls[0].path());
+
+        if(fi.suffix() == "gpx")
+        {
+            event->acceptProposedAction();
+        }
+
+    }
+}
+
+
+void CMainWindow::dropEvent(QDropEvent *event)
+{
+    QList<QUrl> urls = event->mimeData()->urls();
+    QUrl url;
+
+    foreach(url, urls)
+    {
+        QString filename = url.path();
+        QString filter;
+        loadData(filename, filter);
+    }
+
+    event->acceptProposedAction();
+}
+
+
 void CMainWindow::setTitleBar()
 {
-    if(wksFile.isEmpty()) {
+    if(wksFile.isEmpty())
+    {
         setWindowTitle(QString("QLandkarte GT") + (modified ? " *" : ""));
     }
-    else {
+    else
+    {
         setWindowTitle(QString("QLandkarte GT - ") + QFileInfo(wksFile).fileName() + (modified ? " *" : ""));
     }
 }
@@ -401,7 +449,8 @@ void CMainWindow::clearAll()
 {
     QMessageBox::StandardButton res = QMessageBox::question(0, tr("Clear all..."), tr("This will erase all project data like waypoints and tracks."), QMessageBox::Ok|QMessageBox::Cancel, QMessageBox::Ok);
 
-    if(res == QMessageBox::Ok) {
+    if(res == QMessageBox::Ok)
+    {
         CSearchDB::self().clear();
         CMapDB::self().clear();
         CWptDB::self().clear();
@@ -436,31 +485,50 @@ void CMainWindow::setPositionInfo(const QString& info)
 
 void CMainWindow::switchState()
 {
-    if (groupProvidedMenu) {
+    if (groupProvidedMenu)
+    {
         groupProvidedMenu->clear();
         actionGroupProvider->addActionsToMenu(groupProvidedMenu);
     }
 }
 
 
+#if defined(Q_WS_MAC)
+// do not translate on the Mac, so the item is shifted
+#  define tr_nomac(x) (x)
+#else
+#  define tr_nomac(x) tr(x)
+#endif
+
 void CMainWindow::setupMenuBar()
 {
     QMenu * menu;
 
+    menuMostRecent = new QMenu(tr("Load most recent..."),this);
+    menuMostRecent->setIcon(QIcon(":/icons/iconFileLoad16x16.png"));
+
+    QString recent;
+    foreach(recent, mostRecent)
+    {
+        menuMostRecent->addAction(recent, this, SLOT(slotLoadRecent()));
+    }
+
     menu = new QMenu(this);
     menu->setTitle(tr("&File"));
     menu->addAction(QIcon(":/icons/iconOpenMap16x16.png"),tr("Load Map"),this,SLOT(slotLoadMapSet()));
     menu->addSeparator();
     menu->addAction(QIcon(":/icons/iconFileLoad16x16.png"),tr("Load Geo Data"),this,SLOT(slotLoadData()), Qt::CTRL + Qt::Key_L);
     menu->addAction(QIcon(":/icons/iconFileSave16x16.png"),tr("Save Geo Data"),this,SLOT(slotSaveData()), Qt::CTRL + Qt::Key_S);
+    menu->addAction(QIcon(":/icons/iconFileExport16x16.png"),tr("Export Geo Data"),this,SLOT(slotExportData()), Qt::CTRL + Qt::Key_X);
     menu->addAction(QIcon(":/icons/iconFileAdd16x16.png"),tr("Add Geo Data"),this,SLOT(slotAddData()));
+    menu->addMenu(menuMostRecent);
     menu->addSeparator();
     menu->addAction(QIcon(":/icons/iconScreenshot16x16.png"),tr("Device Screenshot ..."),this,SLOT(slotScreenshot()));
     menu->addAction(QIcon(":/icons/iconRaster16x16.png"),tr("Save as image ..."),this,SLOT(slotSaveImage()));
     menu->addAction(QIcon(":/icons/iconPrint16x16.png"),tr("Print Map ..."),this,SLOT(slotPrint()), Qt::CTRL + Qt::Key_P);
     menu->addAction(QIcon(":/icons/iconPrint16x16.png"),tr("Print Diary ..."),this,SLOT(slotPrintPreview()));
     menu->addSeparator();
-    menu->addAction(QIcon(":/icons/iconExit16x16.png"),tr("Exit"),this,SLOT(close()));
+    menu->addAction(QIcon(":/icons/iconExit16x16.png"),tr_nomac("Exit"),this,SLOT(close()));
     menuBar()->addMenu(menu);
 
     //    groupProvidedMenu = new QMenu(this);
@@ -506,17 +574,21 @@ void CMainWindow::setupMenuBar()
 
     menu = new QMenu(this);
     actionGroupProvider->addActionsToMenu(menu,CMenus::MenuBarMenu,CMenus::MainMoreMenu);
-    menu->setTitle(tr("&more"));
+    menu->setTitle(tr("Mor&e"));
     menuBar()->addMenu(menu);
 
     menu = new QMenu(this);
     menu->setTitle(tr("&Setup"));
+#if defined(Q_WS_MAC)
+    menu->addAction(QIcon(":/icons/iconConfig16x16.png"),"&Preferences",this,SLOT(slotConfig()));
+#else
     menu->addAction(QIcon(":/icons/iconConfig16x16.png"),tr("&General"),this,SLOT(slotConfig()));
+#endif
     menuBar()->addMenu(menu);
 
     menu = new QMenu(this);
-    menu->setTitle(tr("&Help"));
-    menu->addAction(QIcon(":/icons/iconGlobe16x16.png"),tr("About &QLandkarte GT"),this,SLOT(slotCopyright()));
+    menu->setTitle(tr_nomac("&Help"));
+    menu->addAction(QIcon(":/icons/iconGlobe16x16.png"),tr_nomac("About &QLandkarte GT"),this,SLOT(slotCopyright()));
     menuBar()->addMenu(menu);
 }
 
@@ -549,15 +621,18 @@ void CMainWindow::keyPressEvent(QKeyEvent * e)
 
 void CMainWindow::closeEvent(QCloseEvent * e)
 {
-    if(!modified) {
+    if(!modified)
+    {
         e->accept();
         return;
     }
 
-    if (maybeSave()) {
+    if (maybeSave())
+    {
         e->accept();
     }
-    else {
+    else
+    {
         e->ignore();
     }
 }
@@ -613,10 +688,12 @@ void CMainWindow::slotLoadData()
 
     bool haveGPSBabel = QProcess::execute("gpsbabel -V") == 0;
     QString formats;
-    if(haveGPSBabel) {
+    if(haveGPSBabel)
+    {
         formats = "All supported files (*.qlb *.gpx *.tcx *.loc *.gdb *.kml);;QLandkarte (*.qlb);;GPS Exchange (*.gpx);;TCX TrainingsCenterExchange (*.tcx);;Geocaching.com - EasyGPS (*.loc);;Mapsource (*.gdb);;Google Earth (*.kml)";
     }
-    else {
+    else
+    {
         formats = "All supported files (*.qlb *.gpx *.tcx);;QLandkarte (*.qlb);;GPS Exchange (*.gpx);;TCX TrainingsCenterExchange (*.tcx)";
     }
 
@@ -631,8 +708,10 @@ void CMainWindow::slotLoadData()
 
     if(filenames.isEmpty()) return;
 
-    if(modified) {
-        if(!maybeSave()) {
+    if(modified)
+    {
+        if(!maybeSave())
+        {
             return;
         }
     }
@@ -645,11 +724,13 @@ void CMainWindow::slotLoadData()
     COverlayDB::self().clear();
 
     QString filename;
-    foreach(filename, filenames){
+    foreach(filename, filenames)
+    {
         loadData(filename, filter);
+        addRecent(filename);
     }
 
-    wksFile.clear();
+    wksFile = filename;
 
     modified = false;
     setTitleBar();
@@ -662,10 +743,12 @@ void CMainWindow::slotAddData()
 {
     bool haveGPSBabel = QProcess::execute("gpsbabel -V") == 0;
     QString formats;
-    if(haveGPSBabel) {
+    if(haveGPSBabel)
+    {
         formats = "All supported files (*.qlb *.gpx *.tcx *.loc *.gdb *.kml);;QLandkarte (*.qlb);;GPS Exchange (*.gpx);;TCX TrainingsCenterExchange (*.tcx);;Geocaching.com - EasyGPS (*.loc);;Mapsource (*.gdb);;Google Earth (*.kml)";
     }
-    else {
+    else
+    {
         formats = "All supported files (*.qlb *.gpx *.tcx);;QLandkarte (*.qlb);;GPS Exchange (*.gpx);;TCX TrainingsCenterExchange (*.tcx)";
     }
 
@@ -680,12 +763,15 @@ void CMainWindow::slotAddData()
         , QFileDialog::DontUseNativeDialog
         );
 
-    for (i = 0; i < filenames.size(); ++i) {
+    for (i = 0; i < filenames.size(); ++i)
+    {
         filename = filenames.at(i);
         if(filename.isEmpty()) return;
 
         QString tmp = wksFile;
         loadData(filename, filter);
+        addRecent(filename);
+
         wksFile = tmp;
 
         modified = true;
@@ -693,6 +779,7 @@ void CMainWindow::slotAddData()
 
         cfg.setValue("geodata/filter",filter);
     }
+
 }
 
 
@@ -707,7 +794,8 @@ void CMainWindow::loadData(QString& filename, const QString& filter)
 
     try
     {
-        if(ext == "QLB") {
+        if(ext == "QLB")
+        {
             CQlb qlb(this);
             qlb.load(filename);
             CMapDB::self().loadQLB(qlb);
@@ -717,7 +805,8 @@ void CMainWindow::loadData(QString& filename, const QString& filter)
             CDiaryDB::self().loadQLB(qlb);
             COverlayDB::self().loadQLB(qlb);
         }
-        else if(ext == "GPX") {
+        else if(ext == "GPX")
+        {
             CGpx gpx(this);
             gpx.load(filename);
             CMapDB::self().loadGPX(gpx);
@@ -727,26 +816,33 @@ void CMainWindow::loadData(QString& filename, const QString& filter)
             CDiaryDB::self().loadGPX(gpx);
             COverlayDB::self().loadGPX(gpx);
         }
-        else if(ext == "TCX") {
+        else if(ext == "TCX")
+        {
             TcxReader tcxReader(this);
-            if (!tcxReader.read(filename)) {
+            if (!tcxReader.read(filename))
+            {
                 throw(tcxReader.errorString());
             }
-            else {
+            else
+            {
                 //emit CTrackDB::self().sigChanged(); //??
                 QRectF r = CTrackDB::self().getBoundingRectF();
-                if (!r.isNull ()) {
+                if (!r.isNull ())
+                {
                     CMapDB::self().getMap().zoom(r.left() * DEG_TO_RAD, r.top() * DEG_TO_RAD, r.right() * DEG_TO_RAD, r.bottom() * DEG_TO_RAD);
                 }
             }
         }
-        else if(ext == "LOC") {
+        else if(ext == "LOC")
+        {
             tmpfile.open();
             loadGPXData = convertData("geo", filename, "gpx", tmpfile.fileName());
-            if (!loadGPXData) {
+            if (!loadGPXData)
+            {
                 QMessageBox::critical(0,tr("Convert error"),"Error in data conversion?",QMessageBox::Ok,QMessageBox::NoButton);
             }
-            else {
+            else
+            {
                 CGpx gpx(this);
                 gpx.load(tmpfile.fileName());
                 CMapDB::self().loadGPX(gpx);
@@ -757,13 +853,16 @@ void CMainWindow::loadData(QString& filename, const QString& filter)
                 COverlayDB::self().loadGPX(gpx);
             }
         }
-        else if(ext == "GDB") {
+        else if(ext == "GDB")
+        {
             tmpfile.open();
             loadGPXData = convertData("gdb", filename, "gpx", tmpfile.fileName());
-            if (!loadGPXData) {
+            if (!loadGPXData)
+            {
                 QMessageBox::critical(0,tr("Convert error"),"Error in data conversion?",QMessageBox::Ok,QMessageBox::NoButton);
             }
-            else {
+            else
+            {
                 CGpx gpx(this);
                 gpx.load(tmpfile.fileName());
                 CMapDB::self().loadGPX(gpx);
@@ -774,13 +873,16 @@ void CMainWindow::loadData(QString& filename, const QString& filter)
                 COverlayDB::self().loadGPX(gpx);
             }
         }
-        else if(ext == "KML") {
+        else if(ext == "KML")
+        {
             tmpfile.open();
             loadGPXData = convertData("kml", filename, "gpx", tmpfile.fileName());
-            if (!loadGPXData) {
+            if (!loadGPXData)
+            {
                 QMessageBox::critical(0,tr("Convert error"),"Error in data conversion?",QMessageBox::Ok,QMessageBox::NoButton);
             }
-            else {
+            else
+            {
                 CGpx gpx(this);
                 gpx.load(tmpfile.fileName());
                 CMapDB::self().loadGPX(gpx);
@@ -793,7 +895,8 @@ void CMainWindow::loadData(QString& filename, const QString& filter)
         }
         wksFile = filename;
     }
-    catch(const QString& msg) {
+    catch(const QString& msg)
+    {
         wksFile.clear();
         QMessageBox:: critical(this,tr("Error"), msg, QMessageBox::Cancel, QMessageBox::Cancel);
     }
@@ -826,18 +929,22 @@ bool CMainWindow::maybeSave()
         "Do you want to save your changes?"),
         QMessageBox::Save | QMessageBox::Discard| QMessageBox::Cancel);
 
-    if (ret == QMessageBox::Save) {
-        if(wksFile.isEmpty()) {
+    if (ret == QMessageBox::Save)
+    {
+        if(wksFile.isEmpty())
+        {
             slotSaveData();
         }
-        else {
+        else
+        {
             QSettings cfg;
             QString filter = cfg.value("geodata/filter","").toString();
             saveData(wksFile, filter);
         }
         return true;
     }
-    else if (ret == QMessageBox::Cancel) {
+    else if (ret == QMessageBox::Cancel)
+    {
         return false;
     }
     return true;
@@ -860,34 +967,56 @@ void CMainWindow::slotSaveData()
     if(filename.isEmpty()) return;
 
     cfg.setValue("geodata/filter",filter);
-
     saveData(filename, filter);
+    addRecent(filename);
 }
 
 
-void CMainWindow::saveData(const QString& fn, const QString& filter)
+void CMainWindow::slotExportData()
+{
+    QString filename = QFileDialog::getSaveFileName( 0, tr("Select output file")
+        ,pathData
+        ,"GPS Exchange (*.gpx)"
+        ,0
+        , QFileDialog::DontUseNativeDialog
+        );
+
+    if(filename.isEmpty()) return;
+
+    saveData(filename, "GPS Exchange (*.gpx)", true);
+    addRecent(filename);
+}
+
+
+void CMainWindow::saveData(const QString& fn, const QString& filter, bool exportFlag)
 {
     QString filename = fn;
     QString ext = filename.right(4);
 
-    if(filter == "QLandkarte (*.qlb)") {
-        if(ext != ".qlb") filename += ".qlb";
-        ext = "QLB";
-    }
-    else if(filter == "GPS Exchange (*.gpx)") {
+    if(exportFlag || filter == "GPS Exchange (*.gpx)")
+    {
         if(ext != ".gpx") filename += ".gpx";
         ext = "GPX";
     }
-    else {
+    else if(filter == "QLandkarte (*.qlb)")
+    {
+        if(ext != ".qlb") filename += ".qlb";
+        ext = "QLB";
+    }
+    else
+    {
         //         filename += ".qlb";
         //         ext = "QLB";
-        if (ext == ".gpx") {
+        if (ext == ".gpx")
+        {
             ext = "GPX";
         }
-        else if (ext == ".qlb") {
+        else if (ext == ".qlb")
+        {
             ext = "QLB";
         }
-        else {
+        else
+        {
             filename += ".qlb";
             ext = "QLB";
         }
@@ -897,7 +1026,8 @@ void CMainWindow::saveData(const QString& fn, const QString& filter)
 
     try
     {
-        if(ext == "QLB") {
+        if(ext == "QLB")
+        {
             CQlb qlb(this);
             CMapDB::self().saveQLB(qlb);
             CWptDB::self().saveQLB(qlb);
@@ -907,12 +1037,14 @@ void CMainWindow::saveData(const QString& fn, const QString& filter)
             COverlayDB::self().saveQLB(qlb);
             qlb.save(filename);
         }
-        else if(ext == "GPX") {
-            CGpx gpx(this);
+        else if(ext == "GPX")
+        {
+            CGpx gpx(this, exportFlag);
             CMapDB::self().saveGPX(gpx);
             CWptDB::self().saveGPX(gpx);
             CTrackDB::self().saveGPX(gpx);
             CRouteDB::self().saveGPX(gpx);
+            gpx.makeExtensions();
             CDiaryDB::self().saveGPX(gpx);
             COverlayDB::self().saveGPX(gpx);
             gpx.save(filename);
@@ -921,7 +1053,8 @@ void CMainWindow::saveData(const QString& fn, const QString& filter)
         wksFile  = filename;
         modified = false;
     }
-    catch(const QString& msg) {
+    catch(const QString& msg)
+    {
         wksFile.clear();
         QMessageBox:: critical(this,tr("Error"), msg, QMessageBox::Cancel, QMessageBox::Cancel);
     }
@@ -958,10 +1091,12 @@ void CMainWindow::slotSaveImage()
 
     CMap3DWidget * map3d = qobject_cast<CMap3DWidget*>(canvasTab->currentWidget());
 
-    if(map3d){
+    if(map3d)
+    {
         map3d->slotSaveImage(filename);
     }
-    else{
+    else
+    {
         QImage img(canvas->size(), QImage::Format_ARGB32);
         canvas->print(img);
         img.save(filename);
@@ -995,62 +1130,80 @@ void CMainWindow::slotDataChanged()
 
     str += "<p>";
     c = CWptDB::self().count();
-    if(c > 0) {
-        if(c == 1) {
+    if(c > 0)
+    {
+        if(c == 1)
+        {
             str += tr("Currently there is %1 <a href='Waypoints'>waypoint</a>, ").arg(c);
         }
-        else {
+        else
+        {
             str += tr("Currently there are %1 <a href='Waypoints'>waypoints</a>, ").arg(c);
         }
     }
-    else {
+    else
+    {
         str += tr("There are no waypoints, ");
     }
 
     c = CTrackDB::self().count();
-    if(c > 0) {
-        if(c == 1) {
+    if(c > 0)
+    {
+        if(c == 1)
+        {
             str += tr(" %1 <a href='Tracks'>track</a>, ").arg(c);
         }
-        else {
+        else
+        {
             str += tr(" %1 <a href='Tracks'>tracks</a>, ").arg(c);
         }
     }
-    else {
+    else
+    {
         str += tr("no tracks, ");
     }
 
     c = CRouteDB::self().count();
-    if(c > 0) {
-        if(c == 1) {
+    if(c > 0)
+    {
+        if(c == 1)
+        {
             str += tr(" %1 <a href='Routes'>route</a> and ").arg(c);
         }
-        else {
+        else
+        {
             str += tr(" %1 <a href='Routes'>routes</a> and ").arg(c);
         }
     }
-    else {
+    else
+    {
         str += tr("no routes and ");
     }
 
     c = COverlayDB::self().count();
-    if(c > 0) {
-        if(c == 1) {
+    if(c > 0)
+    {
+        if(c == 1)
+        {
             str += tr(" %1 <a href='Overlay'>overlay</a>. ").arg(c);
         }
-        else {
+        else
+        {
             str += tr(" %1 <a href='Overlay'>overlays</a>. ").arg(c);
         }
     }
-    else {
+    else
+    {
         str += tr("no overlays. ");
     }
 
     c = CDiaryDB::self().count();
-    if(c > 0) {
+    if(c > 0)
+    {
         str += tr("A <a href='Diary'>diary</a> is loaded.");
     }
-    else {
+    else
+    {
         str += tr("The diary (<a href='Diary'>new</a>) is empty.");
     }
 
@@ -1063,13 +1216,16 @@ void CMainWindow::slotDataChanged()
 
 void CMainWindow::slotOpenLink(const QString& link)
 {
-    if(link == "Diary") {
+    if(link == "Diary")
+    {
         CDiaryDB::self().openEditWidget();
     }
-    else if(link == "Clear") {
+    else if(link == "Clear")
+    {
         clearAll();
     }
-    else {
+    else
+    {
         CMegaMenu::self().switchByKeyWord(link);
     }
 }
@@ -1089,6 +1245,7 @@ void CMainWindow::slotDeviceChanged()
     comboDevice->addItem(tr(""),"");
     comboDevice->addItem(tr("QLandkarte M"), "QLandkarteM");
     comboDevice->addItem(resources->m_devType, "Garmin");
+    comboDevice->addItem(tr("NMEA"), "NMEA");
     comboDevice->addItem(tr("Mikrokopter"), "Mikrokopter");
 
     resources->m_devKey = devKey;
@@ -1102,3 +1259,58 @@ void CMainWindow::slotScreenshot()
     dlg.exec();
 
 }
+
+
+void CMainWindow::slotLoadRecent()
+{
+    QAction * act = qobject_cast<QAction*>(sender());
+    if(act)
+    {
+        QString filename = act->text();
+
+        if(modified)
+        {
+            if(!maybeSave())
+            {
+                return;
+            }
+        }
+
+        CMapDB::self().clear();
+        CWptDB::self().clear();
+        CTrackDB::self().clear();
+        CRouteDB::self().clear();
+        CDiaryDB::self().clear();
+        COverlayDB::self().clear();
+
+        loadData(filename,"");
+
+        wksFile = filename;
+
+        modified = false;
+        setTitleBar();
+    }
+}
+
+
+void CMainWindow::addRecent(const QString& filename)
+{
+    QString recent;
+    foreach(recent, mostRecent)
+    {
+        if(recent == filename) return;
+    }
+
+    if(mostRecent.count() >= 10)
+    {
+        mostRecent.removeLast();
+    }
+    mostRecent.prepend(filename);
+
+    menuMostRecent->clear();
+    foreach(recent, mostRecent)
+    {
+        menuMostRecent->addAction(recent, this, SLOT(slotLoadRecent()));
+    }
+
+}
