@@ -40,6 +40,7 @@ class QComboBox;
 class CActions;
 class CMenus;
 class QSocketNotifier;
+class QAction;
 
 class CMainWindow : public QMainWindow
 {
@@ -66,6 +67,8 @@ class CMainWindow : public QMainWindow
     protected:
         void keyPressEvent(QKeyEvent * e);
         void closeEvent(QCloseEvent * e);
+        void dragEnterEvent(QDragEnterEvent *event);
+        void dropEvent(QDropEvent *event);
 
     private slots:
         void slotReloadArgs();
@@ -77,6 +80,7 @@ class CMainWindow : public QMainWindow
         void slotLoadData();
         void slotAddData();
         void slotSaveData();
+        void slotExportData();
         void slotSaveImage();
         void slotPrint();
         void slotPrintPreview();
@@ -86,15 +90,17 @@ class CMainWindow : public QMainWindow
         void slotCurrentDeviceChanged(int);
         void slotDeviceChanged();
         void slotScreenshot();
+        void slotLoadRecent();
 
     private:
         CMenus *actionGroupProvider;
         void setupMenuBar();
+        void addRecent(const QString& filename);
 
         void loadData(QString& filename, const QString& filter);
         void setTitleBar();
         bool maybeSave();
-        void saveData(const QString& filename, const QString& filter);
+        void saveData(const QString& filename, const QString& filter, bool exportFlag = false);
         bool convertData(const QString& inFormat, const QString& inFile, const QString& outFormat, const QString& outFile);
 
         QMenu *setupMenu;
@@ -152,6 +158,10 @@ class CMainWindow : public QMainWindow
         QComboBox * comboDevice;
 
         QSocketNotifier * snRead;
+
+        QMenu * menuMostRecent;
+
+        QStringList mostRecent;
 };
 
 extern CMainWindow * theMainWindow;
