@@ -46,7 +46,8 @@
 void glError()
 {
     GLenum err = glGetError();
-    while (err != GL_NO_ERROR) {
+    while (err != GL_NO_ERROR)
+    {
         qDebug("glError: %s caught at %s:%u\n",
             (char *)gluErrorString(err), __FILE__, __LINE__);
         err = glGetError();
@@ -70,6 +71,7 @@ CMap3DWidget::CMap3DWidget(QWidget * parent)
 
     xShift = 0;
     yShift = 0;
+    zShift = 0;
     zoomFactor = 1;
 
     eleZoomFactor = cfg.value("map/3D/eleZoomFactor", 1).toDouble();
@@ -89,6 +91,7 @@ CMap3DWidget::CMap3DWidget(QWidget * parent)
     cursorFocus = false;
     cursorPress = false;
     reDraw = false;
+    trackmode = false;
 }
 
 
@@ -122,7 +125,8 @@ void CMap3DWidget::mapResize(const QSize& size)
 
 void CMap3DWidget::loadMap()
 {
-    if (! map.isNull()) {
+    if (! map.isNull())
+    {
         disconnect(map, SIGNAL(destroyed()), this, SLOT(deleteLater()));
         disconnect(map, SIGNAL(sigChanged()), this, SLOT(slotChanged()));
         disconnect(map, SIGNAL(sigResize(const QSize&)), this, SLOT(mapResize(const QSize&)));
@@ -131,7 +135,8 @@ void CMap3DWidget::loadMap()
     assert(!map.isNull());
     // map should be square
     mapSize = map->getSize();
-    if (mapSize.width() != mapSize.height()) {
+    if (mapSize.width() != mapSize.height())
+    {
         int side = qMax(mapSize.width(), mapSize.height());
         map->resize(QSize(side, side));
         mapSize = map->getSize();
@@ -146,10 +151,14 @@ void CMap3DWidget::loadMap()
 void CMap3DWidget::loadTrack()
 {
     if (!track.isNull())
+    {
         disconnect(track, SIGNAL(sigChanged()), this, SLOT(slotTrackChanged()));
+    }
     track = CTrackDB::self().highlightedTrack();
     if (!track.isNull())
+    {
         connect(track, SIGNAL(sigChanged()), this, SLOT(slotTrackChanged()));
+    }
     emit sigTrackChanged();
 }
 
@@ -193,6 +202,42 @@ void CMap3DWidget::changeMode()
     slotChanged();
 }
 
+void CMap3DWidget::changeTrackmode()
+{
+    if(track.isNull())
+    {
+        return;
+    }
+
+    double ele1;
+    XY pt1;
+    IMap& dem = CMapDB::self().getDEM();
+    CTrack::pt_t trkpt = track->getTrackPoints().first();
+
+
+    pt1.u = trkpt.lon * DEG_TO_RAD;
+    pt1.v = trkpt.lat * DEG_TO_RAD;
+    if (mapEleAct->isChecked())
+    {
+        ele1 = dem.getElevation(pt1.u, pt1.v) + 1;
+    }
+    else
+    {
+        ele1 = trkpt.ele;
+    }
+
+    map->convertRad2Pt(pt1.u, pt1.v);
+    convertPt23D(pt1.u, pt1.v, ele1);
+
+    qDebug() << pt1.u << pt1.v << ele1;
+
+    xShift = - pt1.u;
+    yShift = - pt1.v;
+    zShift = - ele1;
+
+    zoomFactor = 1.0;
+    updateGL();
+}
 
 void CMap3DWidget::eleZoomOut()
 {
@@ -262,12 +307,14 @@ void CMap3DWidget::contextMenuEvent(QContextMenuEvent *event)
     selWpt = 0;
     // find the waypoint close to the cursor
     QMap<QString,CWpt*>::const_iterator wpt = CWptDB::self().begin();
-    while(wpt != CWptDB::self().end()) {
+    while(wpt != CWptDB::self().end())
+    {
         double u = (*wpt)->lon * DEG_TO_RAD;
         double v = (*wpt)->lat * DEG_TO_RAD;
         map->convertRad2Pt(u,v);
 
-        if(((x - u) * (x - u) + (y - v) * (y - v)) < 1225) {
+        if(((x - u) * (x - u) + (y - v) * (y - v)) < 1225)
+        {
             selWpt = *wpt;
             break;
         }
@@ -276,10 +323,12 @@ void CMap3DWidget::contextMenuEvent(QContextMenuEvent *event)
     }
 
     QMenu menu(this);
-    if (selWpt.isNull()) {
+    if (selWpt.isNull())
+    {
         menu.addAction(QPixmap(":/icons/iconAdd16x16.png"),tr("Add Waypoint ..."),this,SLOT(slotAddWpt()));
     }
-    else {
+    else
+    {
         menu.addAction(QPixmap(":/icons/iconClipboard16x16.png"),tr("Copy Pos. Waypoint"),this,SLOT(slotCopyPositionWpt()));
         menu.addAction(QPixmap(":/icons/iconEdit16x16.png"),tr("Edit Waypoint..."),this,SLOT(slotEditWpt()));
         if(!selWpt->sticky)
@@ -296,11 +345,13 @@ void CMap3DWidget::contextMenuEvent(QContextMenuEvent *event)
     menu.addAction(showTrackAct);
     menu.addAction(mapEleAct);
 
-    if(track.isNull()) {
+    if(track.isNull())
+    {
         showTrackAct->setEnabled(false);
         mapEleAct->setEnabled(false);
     }
-    else {
+    else
+    {
         showTrackAct->setEnabled(true);
         mapEleAct->setEnabled(true);
     }
@@ -424,135 +475,6 @@ float CMap3DWidget::getRegionValue(float *buffer, int x, int y)
 }
 
 
-#if 0                            // set to 1 for old elevation processing
-void CMap3DWidget::draw3DMap()
-{
-    double w = mapSize.width();
-    double h = mapSize.height();
-
-    int i, iv, it, j, k, cur, end;
-    double step = 5;
-    double x, y, u, v;
-    GLdouble *vertices;
-    GLdouble *texCoords;
-    GLuint idx[4];
-    int num = (w / step + 2);
-    glEnableClientState(GL_VERTEX_ARRAY);
-    glEnableClientState(GL_TEXTURE_COORD_ARRAY);
-    glEnable(GL_TEXTURE_2D);
-    glBindTexture(GL_TEXTURE_2D, mapTexture);
-
-    IMap& dem = CMapDB::self().getDEM();
-    /*
-     * next code can be more optimal if used array of coordinates or VBO
-     */
-    vertices = new GLdouble[num * 3 * 2];
-    texCoords = new GLdouble[num * 2 * 2];
-    it = 0;
-    idx[0] = 0 + num;
-    idx[1] = 1 + num;
-    idx[2] = 1;
-    idx[3] = 0;
-    glVertexPointer(3, GL_DOUBLE, 0, vertices);
-    glTexCoordPointer(2, GL_DOUBLE, 0, texCoords);
-    glColor3f(1.0, 0.0, 0.0);
-    glPointSize(2.0);
-
-    for (y = 0; y < h - step; y += step) {
-        it = it % (num * 4);
-        end = it + num * 2;
-        for (x = 0, iv = (it / 2) * 3; it < end; x += step, iv += 3, it += 2) {
-            vertices[iv + 0] = x;
-            vertices[iv + 1] = y;
-            u = x;
-            v = y;
-            texCoords[it  + 0] = u / w;
-            texCoords[it + 1] = 1 - v / h;
-            map->convertPt2Rad(u, v);
-            // next step of optimization will be get elevation for the set of points
-            // read line from DEM file is more effectively
-            vertices[iv + 2] = dem.getElevation(u, v);
-            if  (vertices[iv + 2] > 5000 || vertices[iv + 2] < 0)
-                qDebug() << vertices[iv + 0] << " " << vertices[iv + 1] << " " << vertices[iv + 2] << end;
-            convertPt23D(vertices[iv + 0], vertices[iv + 1], vertices[iv + 2]);
-        }
-
-        for (j = 0; j < 4; j++)
-            idx[j] = idx[j] % (num * 2);
-
-        if (y < step)
-            continue;
-
-        for (k = 0; k < num - 1; k ++) {
-            glDrawElements(GL_QUADS, 4, GL_UNSIGNED_INT, idx);
-            for (j = 0; j < 4; j++)
-                idx[j]++;
-        }
-        for (j = 0; j < 4; j++)
-            idx[j]++;
-    }
-    delete [] vertices;
-    delete [] texCoords;
-    glDisable(GL_TEXTURE_2D);
-}
-
-
-void CMap3DWidget::updateElevationLimits()
-{
-    double x, y, u, v, ele;
-    double w = mapSize.width();
-    double h = mapSize.height();
-    double step = 5;
-    IMap& dem = CMapDB::self().getDEM();
-
-    u = 0;
-    v = 0;
-    map->convertPt2Rad(u, v);
-    minElevation = maxElevation = dem.getElevation(u,v);
-
-    for (y = 0; y < h - step; y += step)
-    for (x = 0; x < w; x += step) {
-        u = x;
-        v = y;
-        map->convertPt2Rad(u, v);
-        // FIXME can't use map instead of dem. need investigation.
-        ele = dem.getElevation(u,v);
-        if (ele > maxElevation)
-            maxElevation = ele;
-
-        if (ele < minElevation)
-            minElevation = ele;
-    }
-
-    if (! track.isNull() && (maxElevation - minElevation < 1)) {
-        /*selected track exist and dem isn't present for this map*/
-        QList<CTrack::pt_t>& trkpts = track->getTrackPoints();
-        QList<CTrack::pt_t>::const_iterator trkpt = trkpts.begin();
-        maxElevation = trkpt->ele;
-        minElevation = trkpt->ele;
-        while(trkpt != trkpts.end()) {
-            if(trkpt->flags & CTrack::pt_t::eDeleted) {
-                ++trkpt; continue;
-            }
-            if (trkpt->ele > maxElevation)
-                maxElevation = trkpt->ele;
-            if (trkpt->ele < minElevation)
-                minElevation = trkpt->ele;
-            ++trkpt;
-        }
-    }
-
-    if (maxElevation - minElevation < 1) {
-        /*selected track and deb are absent*/
-        maxElevation = 1;
-        minElevation = 0;
-    }
-
-}
-
-
-#else
-
 void CMap3DWidget::drawSkybox(double x, double y, double z, double xs, double ys, double zs)
 {
     glTexParameteri( GL_TEXTURE_2D, GL_TEXTURE_WRAP_S, GL_CLAMP_TO_EDGE );
@@ -631,11 +553,13 @@ inline void getNormal(GLdouble *a, GLdouble *b, GLdouble *c, GLdouble *r)
 {
     GLdouble v1[3], v2[3];
     int i;
-    for (i = 0; i < 3; i++) {
+    for (i = 0; i < 3; i++)
+    {
         v1[i] = c[i] - a[i];
         v2[i] = c[i] - b[i];
     }
-    for (i =0; i < 3; i++) {
+    for (i =0; i < 3; i++)
+    {
         r[i] = v1[(i + 1) % 3] * v2[(i + 2) % 3] - v1[(i + 2) % 3] * v2[(i + 1) % 3];
     }
 }
@@ -665,19 +589,22 @@ void CMap3DWidget::draw3DMap()
     int xcount, ycount;
     // increment xcount, because the number of points are on one more
     // than number of lengths |--|--|--|--|
-    if (map->getFastDrawFlag()) {
+    if (map->getFastDrawFlag())
+    {
         xcount = (w / (step * 10.0) + 1);
         ycount = (h / (step * 10.0) + 1);
 
     }
-    else {
+    else
+    {
         xcount = (w / step + 1);
         ycount = (h / step + 1);
     }
 
     qint16 *eleData;
     eleData = getEleRegion(xcount, ycount);
-    if (eleData == NULL) {
+    if (eleData == NULL)
+    {
         qDebug() << "can't get elevation data";
         qDebug() << "draw flat map";
         drawFlatMap();
@@ -687,7 +614,7 @@ void CMap3DWidget::draw3DMap()
     double current_step_x = w / (double) (xcount - 1);
     double current_step_y = h / (double) (ycount - 1);
 
-    int ix, iy, iv, it, j, k, end;
+    int ix=0, iy, iv, it, j, k, end;
     double x, y, u, v;
     GLdouble *vertices;
     GLdouble *texCoords;
@@ -719,7 +646,8 @@ void CMap3DWidget::draw3DMap()
     glColor3f(1.0, 0.0, 0.0);
     glPointSize(2.0);
 
-    for (iy = 0, y = 0; iy < ycount; y += current_step_y, iy++) {
+    for (iy = 0, y = 0; iy < ycount; y += current_step_y, iy++)
+    {
         /* array vertices contain two lines ( previouse and current)
          * they change position that avoid memcopy
          * one time current line is at the begin of array vertices,
@@ -728,7 +656,8 @@ void CMap3DWidget::draw3DMap()
         iv = iv % (xcount * 3 * 2);
         it = it % (xcount * 2 * 2);
         end = ix + xcount;
-        for (x = 0, ix = 0; ix < xcount; x += current_step_x, iv += 3, it += 2, ix++) {
+        for (x = 0, ix = 0; ix < xcount; x += current_step_x, iv += 3, it += 2, ix++)
+        {
             vertices[iv + 0] = x;
             vertices[iv + 1] = y;
             u = x;
@@ -757,7 +686,8 @@ void CMap3DWidget::draw3DMap()
         if (iy == 0)
             continue;
 
-        for (k = 0; k < xcount - 1; k ++) {
+        for (k = 0; k < xcount - 1; k ++)
+        {
             glDrawElements(GL_QUADS, 4, GL_UNSIGNED_INT, idx);
             for (j = 0; j < 4; j++)
                 idx[j]++;
@@ -790,28 +720,35 @@ void CMap3DWidget::updateElevationLimits()
 
     eleData = getEleRegion(xcount, ycount);
     minElevation = maxElevation = 0;
-    if (eleData != NULL) {
+    if (eleData != NULL)
+    {
         minElevation = maxElevation = eleData[0];
 
         for (i = 0; i < xcount; i++)
-        for (j = 0; j < ycount; j++) {
-            ele = eleData[i + j * xcount];
-            if (ele > maxElevation)
-                maxElevation = ele;
+        {
+            for (j = 0; j < ycount; j++)
+            {
+                ele = eleData[i + j * xcount];
+                if (ele > maxElevation)
+                    maxElevation = ele;
 
-            if (ele < minElevation)
-                minElevation = ele;
+                if (ele < minElevation)
+                    minElevation = ele;
+            }
         }
     }
 
-    if (! track.isNull() && (maxElevation - minElevation < 1)) {
+    if (! track.isNull() && (maxElevation - minElevation < 1))
+    {
         /*selected track exist and dem isn't present for this map*/
         QList<CTrack::pt_t>& trkpts = track->getTrackPoints();
         QList<CTrack::pt_t>::const_iterator trkpt = trkpts.begin();
         maxElevation = trkpt->ele;
         minElevation = trkpt->ele;
-        while(trkpt != trkpts.end()) {
-            if(trkpt->flags & CTrack::pt_t::eDeleted) {
+        while(trkpt != trkpts.end())
+        {
+            if(trkpt->flags & CTrack::pt_t::eDeleted)
+            {
                 ++trkpt; continue;
             }
             if (trkpt->ele > maxElevation)
@@ -822,14 +759,15 @@ void CMap3DWidget::updateElevationLimits()
         }
     }
 
-    if (maxElevation - minElevation < 1) {
+    if (maxElevation - minElevation < 1)
+    {
         /*selected track and deb are absent*/
         maxElevation = 1;
         minElevation = 0;
     }
     delete [] eleData;
 }
-#endif
+
 
 void CMap3DWidget::drawTrack()
 {
@@ -838,7 +776,8 @@ void CMap3DWidget::drawTrack()
     double ele1, ele2;
     IMap& dem = CMapDB::self().getDEM();
 
-    if (! track.isNull()) {
+    if (! track.isNull())
+    {
         XY pt1, pt2;
 
         QList<CTrack::pt_t>& trkpts = track->getTrackPoints();
@@ -853,8 +792,10 @@ void CMap3DWidget::drawTrack()
         map->convertRad2Pt(pt1.u, pt1.v);
         convertPt23D(pt1.u, pt1.v, ele1);
 
-        while(trkpt != trkpts.end()) {
-            if(trkpt->flags & CTrack::pt_t::eDeleted) {
+        while(trkpt != trkpts.end())
+        {
+            if(trkpt->flags & CTrack::pt_t::eDeleted)
+            {
                 ++trkpt; continue;
             }
             pt2.u = trkpt->lon * DEG_TO_RAD;
@@ -869,7 +810,8 @@ void CMap3DWidget::drawTrack()
             quad(pt1.u, pt1.v, ele1, pt2.u, pt2.v, ele2);
 
             //draw selected points
-            if (trkpt->flags & CTrack::pt_t::eSelected) {
+            if (trkpt->flags & CTrack::pt_t::eSelected)
+            {
                 glBegin(GL_LINES);
                 glColor3f(1.0, 0.0, 0.0);
                 glVertex3d(pt1.u, pt1.v, ele1);
@@ -929,7 +871,8 @@ void CMap3DWidget::makeTrackObject()
 void CMap3DWidget::setXRotation(double angle)
 {
     normalizeAngle(&angle);
-    if (angle > 0 && angle < 90) {
+    if (angle > 0 && angle < 90)
+    {
         xRot = angle;
         emit xRotationChanged(angle);
         updateGL();
@@ -940,7 +883,8 @@ void CMap3DWidget::setXRotation(double angle)
 void CMap3DWidget::setZRotation(double angle)
 {
     normalizeAngle(&angle);
-    if (angle != zRot) {
+    if (angle != zRot)
+    {
         zRot = angle;
         emit zRotationChanged(angle);
         updateGL();
@@ -963,7 +907,8 @@ void CMap3DWidget::initializeGL()
 
     glClearColor(1.0, 1.0, 1.0, 0.0);
     int i;
-    for (i = 0; i < 6; i++) {
+    for (i = 0; i < 6; i++)
+    {
         QImage img(tr(":/skybox/%1.bmp").arg(i));
         skyBox[i] = bindTexture(img, GL_TEXTURE_2D);
     }
@@ -988,7 +933,8 @@ void CMap3DWidget::lightTurn()
 
 void CMap3DWidget::paintGL()
 {
-    if (reDraw) {
+    if (reDraw)
+    {
         reDraw = false;
         QApplication::setOverrideCursor(Qt::WaitCursor);
         deleteTexture(mapTexture);
@@ -1005,7 +951,7 @@ void CMap3DWidget::paintGL()
     glTranslated(0.0, 0.0, -side);
     glRotated(-xRot, 1.0, 0.0, 0.0);
     glScalef(zoomFactor, zoomFactor, zoomFactor);
-    glTranslated(xShift * 2, 2 * yShift, 0.0);
+    glTranslated(xShift, yShift, zShift);
 
     glRotated(zRot, 0.0, 0.0, 1.0);
 
@@ -1015,7 +961,8 @@ void CMap3DWidget::paintGL()
     glScalef(1.0, 1.0, eleZoomFactor * (mapSize.width() / 10.0) / (maxElevation - minElevation));
     glTranslated(0.0, 0.0, -minElevation);
 
-    if (light) {
+    if (light)
+    {
         glTexEnvf(GL_TEXTURE_ENV, GL_TEXTURE_ENV_MODE, GL_MODULATE);
         glEnable(GL_LIGHTING);
         glEnable(GL_LIGHT0);
@@ -1037,7 +984,8 @@ void CMap3DWidget::paintGL()
     }
 
     glCallList(objectMap);
-    if (light) {
+    if (light)
+    {
         glTexEnvf(GL_TEXTURE_ENV, GL_TEXTURE_ENV_MODE, GL_DECAL);
         glDisable(GL_LIGHT0);
         glDisable(GL_LIGHTING);
@@ -1066,7 +1014,8 @@ void CMap3DWidget::paintGL()
 
     glBegin(GL_LINES);
     glColor3f(0.5, 0.5, 0.5);
-    for(i = -n; i <= n; i ++) {
+    for(i = -n; i <= n; i ++)
+    {
         glVertex3f(-d * n, i * d, minElevation);
         glVertex3f(d * n, i * d, minElevation);
 
@@ -1079,7 +1028,8 @@ void CMap3DWidget::paintGL()
     const QMap<QString,CWpt*>& wpts = CWptDB::self().getWpts();
 
     QMap<QString,CWpt*>::const_iterator wpt  = wpts.begin();
-    while(wpt != wpts.end()) {
+    while(wpt != wpts.end())
+    {
         drawWpt(wpt.value());
         ++wpt;
     }
@@ -1135,7 +1085,8 @@ void CMap3DWidget::drawWpt(CWpt *wpt)
     int i, j;
     GLdouble a[4], b[4] = {u,v,ele,1};
     glGetDoublev(GL_MODELVIEW_MATRIX, modelview);
-    for (i = 0; i < 4; i++) {
+    for (i = 0; i < 4; i++)
+    {
         a[i] = 0;
         for (j = 0; j < 4; j ++)
             a[i] += modelview[i+j*4] * b[j];
@@ -1278,8 +1229,10 @@ void CMap3DWidget::mouseDoubleClickEvent ( QMouseEvent * event )
 
     QList<CTrack::pt_t>& pts          = track->getTrackPoints();
     QList<CTrack::pt_t>::iterator pt  = pts.begin();
-    while(pt != pts.end()) {
-        if(pt->flags & CTrack::pt_t::eDeleted) {
+    while(pt != pts.end())
+    {
+        if(pt->flags & CTrack::pt_t::eDeleted)
+        {
             ++pt; continue;
         }
         p.u = pt->lon * DEG_TO_RAD;
@@ -1288,14 +1241,16 @@ void CMap3DWidget::mouseDoubleClickEvent ( QMouseEvent * event )
 
         int d2 = abs(x0 - p.u) + abs(y0 - p.v);
 
-        if(d2 < d1) {
+        if(d2 < d1)
+        {
             selTrkPt = &(*pt);
             d1 = d2;
         }
 
         ++pt;
     }
-    if (selTrkPt) {
+    if (selTrkPt)
+    {
         selTrkPt->flags |= CTrack::pt_t::eSelected;
         track->setPointOfFocus(selTrkPt->idx);
         updateGL();
@@ -1307,7 +1262,8 @@ void CMap3DWidget::mousePressEvent(QMouseEvent *event)
 {
     qDebug() << "CMap3DWidget::mousePressEvent";
     lastPos = event->pos();
-    if (!cursorPress) {
+    if (!cursorPress)
+    {
         QApplication::setOverrideCursor(QCursor(QPixmap(":/cursors/cursorMove")));
         cursorPress = true;
     }
@@ -1317,7 +1273,8 @@ void CMap3DWidget::mousePressEvent(QMouseEvent *event)
 void CMap3DWidget::mouseReleaseEvent(QMouseEvent *event)
 {
     qDebug() << "CMap3DWidget::mouseReleaseEvent";
-    if (cursorPress) {
+    if (cursorPress)
+    {
         QApplication::restoreOverrideCursor();
         cursorPress = false;
     }
@@ -1356,7 +1313,8 @@ void CMap3DWidget::keyPressEvent ( QKeyEvent * event )
 
     qint32 dx = 0, dy = 0;
     qint32 zoomMap = 0;
-    switch (event->key()) {
+    switch (event->key())
+    {
         case Qt::Key_Up:
             dy -= 100;
             break;
@@ -1388,11 +1346,13 @@ void CMap3DWidget::keyPressEvent ( QKeyEvent * event )
             event->ignore();
             return;
     }
-    if (zoomMap) {
+    if (zoomMap)
+    {
         map->zoom(zoomMap > 0 ? true : false, QPoint(mapSize.width() / 2, mapSize.height() / 2));
     }
 
-    if (dx || dy) {
+    if (dx || dy)
+    {
         map->move(QPoint(dx, dy), QPoint(0, 0));
     }
     updateGL();
@@ -1411,10 +1371,12 @@ void CMap3DWidget::mouseMoveEvent(QMouseEvent *event)
     int dx = event->x() - lastPos.x();
     int dy = event->y() - lastPos.y();
 
-    if (pressedKeys.contains(Qt::Key_H)) {
+    if (pressedKeys.contains(Qt::Key_H))
+    {
         zLight += dy;
     }
-    else if (pressedKeys.contains(Qt::Key_L)) {
+    else if (pressedKeys.contains(Qt::Key_L))
+    {
         double x0, y0, z0;
         double x1, y1, z1;
         x0 = event->x();
@@ -1429,7 +1391,8 @@ void CMap3DWidget::mouseMoveEvent(QMouseEvent *event)
         yLight += (y0 / (z -z0) * z - y1 / (z -z1) * z);
         updateGL();
     }
-    else if (pressedKeys.contains(Qt::Key_M)) {
+    else if (pressedKeys.contains(Qt::Key_M))
+    {
         QPoint p1 = event->pos(), p2 = lastPos;
         convertDsp2Z0(p1);
         convertDsp2Z0(p2);
@@ -1437,11 +1400,13 @@ void CMap3DWidget::mouseMoveEvent(QMouseEvent *event)
         dy = p1.y() - p2.y();
         map->move(QPoint(dx, dy), QPoint(0, 0));
     }
-    else if (event->buttons() & Qt::LeftButton) {
+    else if (event->buttons() & Qt::LeftButton)
+    {
         setXRotation(xRot - xRotSens * dy);
         setZRotation(zRot + zRotSens * dx);
     }
-    else if (event->buttons() & Qt::MidButton) {
+    else if (event->buttons() & Qt::MidButton)
+    {
         xShift += dx / zoomFactor;
         yShift -= dy / zoomFactor;
     }
@@ -1496,15 +1461,19 @@ void CMap3DWidget::normalizeAngle(double *angle)
 void CMap3DWidget::wheelEvent ( QWheelEvent * e )
 {
     bool in = CResources::self().flipMouseWheel() ? (e->delta() > 0) : (e->delta() < 0);
-    if (pressedKeys.contains(Qt::Key_M)) {
+    if (pressedKeys.contains(Qt::Key_M))
+    {
         map->zoom(in, QPoint(mapSize.width() / 2, mapSize.height() / 2));
     }
-    else {
-        if (in) {
+    else
+    {
+        if (in)
+        {
             qDebug() << "in" << endl;
             zoomFactor *= 1.1;
         }
-        else {
+        else
+        {
             qDebug() << "out" << endl;
             zoomFactor /= 1.1;
         }
@@ -1515,7 +1484,8 @@ void CMap3DWidget::wheelEvent ( QWheelEvent * e )
 
 void CMap3DWidget::enterEvent(QEvent * )
 {
-    if (!cursorFocus) {
+    if (!cursorFocus)
+    {
         QApplication::setOverrideCursor(QCursor(QPixmap(":/cursors/cursorMoveMap"), 0, 0));
         cursorFocus = true;
     }
@@ -1525,12 +1495,14 @@ void CMap3DWidget::enterEvent(QEvent * )
 
 void CMap3DWidget::leaveEvent(QEvent * )
 {
-    if (cursorPress) {
+    if (cursorPress)
+    {
         QApplication::restoreOverrideCursor();
         cursorPress = false;
     }
 
-    if (cursorFocus) {
+    if (cursorFocus)
+    {
         QApplication::restoreOverrideCursor();
         cursorFocus = false;
     }
