@@ -51,18 +51,21 @@ CMapGeoTiff::CMapGeoTiff(const QString& fn, CCanvas * parent)
     filename = fn;
 
     dataset = (GDALDataset*)GDALOpen(filename.toUtf8(),GA_ReadOnly);
-    if(dataset == 0) {
+    if(dataset == 0)
+    {
         QMessageBox::warning(0, tr("Error..."), tr("Failed to load file: %1").arg(filename));
         return;
     }
 
     rasterBandCount = dataset->GetRasterCount();
 
-    if(rasterBandCount == 1) {
+    if(rasterBandCount == 1)
+    {
         GDALRasterBand * pBand;
         pBand = dataset->GetRasterBand(1);
 
-        if(pBand == 0) {
+        if(pBand == 0)
+        {
             delete dataset; dataset = 0;
             QMessageBox::warning(0, tr("Error..."), tr("Failed to load file: %1").arg(filename));
             return;
@@ -70,19 +73,24 @@ CMapGeoTiff::CMapGeoTiff(const QString& fn, CCanvas * parent)
 
         qDebug() << pBand->GetColorInterpretation();
 
-        if(pBand->GetColorInterpretation() ==  GCI_PaletteIndex ) {
+        if(pBand->GetColorInterpretation() ==  GCI_PaletteIndex )
+        {
             GDALColorTable * pct = pBand->GetColorTable();
-            for(int i=0; i < pct->GetColorEntryCount(); ++i) {
+            for(int i=0; i < pct->GetColorEntryCount(); ++i)
+            {
                 const GDALColorEntry& e = *pct->GetColorEntry(i);
                 colortable << qRgba(e.c1, e.c2, e.c3, e.c4);
             }
         }
-        else if(pBand->GetColorInterpretation() ==  GCI_GrayIndex ) {
-            for(int i=0; i < 256; ++i) {
+        else if(pBand->GetColorInterpretation() ==  GCI_GrayIndex )
+        {
+            for(int i=0; i < 256; ++i)
+            {
                 colortable << qRgba(i, i, i, 255);
             }
         }
-        else {
+        else
+        {
             delete dataset; dataset = 0;
             QMessageBox::warning(0, tr("Error..."), tr("File must be 8 bit palette or gray indexed."));
             return;
@@ -91,7 +99,8 @@ CMapGeoTiff::CMapGeoTiff(const QString& fn, CCanvas * parent)
         int success = 0;
         double idx = pBand->GetNoDataValue(&success);
 
-        if(success) {
+        if(success)
+        {
             QColor tmp(colortable[idx]);
             tmp.setAlpha(0);
             colortable[idx] = tmp.rgba();
@@ -108,7 +117,8 @@ CMapGeoTiff::CMapGeoTiff(const QString& fn, CCanvas * parent)
     qDebug() << ptr;
 
     pjsrc = pj_init_plus(ptr);
-    if(pjsrc == 0) {
+    if(pjsrc == 0)
+    {
         delete dataset; dataset = 0;
         QMessageBox::warning(0, tr("Error..."), tr("No georeference information found."));
         return;
@@ -120,14 +130,16 @@ CMapGeoTiff::CMapGeoTiff(const QString& fn, CCanvas * parent)
     double adfGeoTransform[6];
     dataset->GetGeoTransform( adfGeoTransform );
 
-    if (pj_is_latlong(pjsrc)) {
+    if (pj_is_latlong(pjsrc))
+    {
         xscale  = adfGeoTransform[1] * DEG_TO_RAD;
         yscale  = adfGeoTransform[5] * DEG_TO_RAD;
 
         xref1   = adfGeoTransform[0] * DEG_TO_RAD;
         yref1   = adfGeoTransform[3] * DEG_TO_RAD;
     }
-    else {
+    else
+    {
         xscale  = adfGeoTransform[1];
         yscale  = adfGeoTransform[5];
 
@@ -167,13 +179,15 @@ CMapGeoTiff::~CMapGeoTiff()
     if(pjsrc) pj_free(pjsrc);
     if(dataset) delete dataset;
 
-    if(quadraticZoom) {
+    if(quadraticZoom)
+    {
         QSettings cfg;
         cfg.setValue("maps/quadraticZoom", quadraticZoom->isChecked());
         delete quadraticZoom;
     }
 }
 
+
 bool CMapGeoTiff::is32BitRgb()
 {
     return rasterBandCount > 1;
@@ -187,10 +201,12 @@ void CMapGeoTiff::draw(QPainter& p)
     draw();
 
     QString str;
-    if(zoomFactor < 1.0) {
+    if(zoomFactor < 1.0)
+    {
         str = tr("Overzoom x%1").arg(1/zoomFactor,0,'f',0);
     }
-    else {
+    else
+    {
         str = tr("Zoom level x%1").arg(zoomidx);
     }
 
@@ -227,7 +243,8 @@ void CMapGeoTiff::draw()
 
     //     qDebug() << maparea << viewport << intersect;
 
-    if(intersect.isValid()) {
+    if(intersect.isValid())
+    {
 
         // x/y offset [pixel] into file matrix
         qint32 xoff = (intersect.left()   - xref1) / xscale;
@@ -246,11 +263,13 @@ void CMapGeoTiff::draw()
 
         //         qDebug() << xoff << yoff << pxx << pxy << w << h;
 
-        if(w != 0 && h != 0) {
+        if(w != 0 && h != 0)
+        {
 
             CPLErr err = CE_Failure;
 
-            if(rasterBandCount == 1) {
+            if(rasterBandCount == 1)
+            {
                 GDALRasterBand * pBand;
                 pBand = dataset->GetRasterBand(1);
 
@@ -264,31 +283,36 @@ void CMapGeoTiff::draw()
                     ,w,h
                     ,GDT_Byte,0,0);
 
-                if(!err) {
+                if(!err)
+                {
                     double xx = intersect.left(), yy = intersect.bottom();
                     convertM2Pt(xx,yy);
                     _p_.drawPixmap(xx,yy,QPixmap::fromImage(img));
                 }
             }
-            else {
+            else
+            {
                 QImage img(w,h, QImage::Format_ARGB32);
                 QVector<quint8> buffer(w*h);
 
                 img.fill(qRgba(255,255,255,255));
 
-                for(int b = 1; b <= rasterBandCount; ++b) {
+                for(int b = 1; b <= rasterBandCount; ++b)
+                {
 
                     GDALRasterBand * pBand;
                     pBand = dataset->GetRasterBand(b);
 
                     err = pBand->RasterIO(GF_Read, (int)xoff, (int)yoff, pxx, pxy, buffer.data(), w, h, GDT_Byte, 0, 0);
 
-                    if(!err) {
+                    if(!err)
+                    {
                         quint8 * pTar   = img.bits() - (pBand->GetColorInterpretation() - 5);
                         quint8 * pSrc   = buffer.data();
                         const int size  = buffer.size();
 
-                        for(int i = 0; i < size; ++i) {
+                        for(int i = 0; i < size; ++i)
+                        {
                             *pTar = *pSrc;
                             pTar += 4;
                             pSrc += 1;
@@ -296,7 +320,8 @@ void CMapGeoTiff::draw()
                     }
                 }
 
-                if(!err) {
+                if(!err)
+                {
                     double xx = intersect.left(), yy = intersect.bottom();
                     convertM2Pt(xx,yy);
                     _p_.drawImage(xx,yy,img);
@@ -349,17 +374,21 @@ void CMapGeoTiff::zoom(bool zoomIn, const QPoint& p0)
     p1.v = p0.y();
     convertPt2Rad(p1.u, p1.v);
 
-    if(quadraticZoom->isChecked()) {
+    if(quadraticZoom->isChecked())
+    {
 
-        if(zoomidx > 1) {
+        if(zoomidx > 1)
+        {
             zoomidx = pow(2.0, ceil(log(zoomidx*1.0)/log(2.0)));
             zoomidx = zoomIn ? (zoomidx>>1) : (zoomidx<<1);
         }
-        else {
+        else
+        {
             zoomidx += zoomIn ? -1 : 1;
         }
     }
-    else {
+    else
+    {
         zoomidx += zoomIn ? -1 : 1;
     }
     // sigChanged will be sent at the end of this function
@@ -390,7 +419,8 @@ void CMapGeoTiff::zoom(qint32& level)
     if(pjsrc == 0) return;
 
     // no level less than 1
-    if(level < 1) {
+    if(level < 1)
+    {
         zoomFactor  = 1.0 / - (level - 2);
         qDebug() << "zoom:" << zoomFactor;
         return;
@@ -424,10 +454,12 @@ void CMapGeoTiff::zoom(double lon1, double lat1, double lon2, double lat2)
     int z2 = dV / size.height();
 
     zoomFactor = (z1 > z2 ? z1 : z2)  + 1;
-    if(quadraticZoom->isChecked()) {
+    if(quadraticZoom->isChecked())
+    {
         zoomFactor = zoomidx = pow(2.0, ceil(log(zoomFactor)/log(2.0)));
     }
-    else {
+    else
+    {
         zoomidx = zoomFactor;
     }
 
