@@ -21,6 +21,7 @@
 
 #include "IMap.h"
 #include "CGarminTile.h"
+#include "IGarminTyp.h"
 #include <QMap>
 #include <QPen>
 #include <QBrush>
@@ -32,6 +33,7 @@ class QTimer;
 class QTextDocument;
 class CGarminIndex;
 class QCheckBox;
+class QComboBox;
 
 class CMapTDB : public IMap
 {
@@ -71,10 +73,14 @@ class CMapTDB : public IMap
 
     private slots:
         void slotPoiLabels(bool checked);
+        void slotNightView(bool checked);
+        void slotDetailChanged(int idx);
+        void slotLanguageChanged(int idx);
 
     private:
         friend class CDlgMapTDBConfig;
         void setup();
+
         struct strlbl_t
         {
             QPoint  pt;
@@ -108,22 +114,8 @@ class CMapTDB : public IMap
         void getInfoPolylines(QPoint& pt, QMultiMap<QString, QString>& dict);
         void collectText(CGarminPolygon& item, QPolygonF& line, QFont& font, QFontMetricsF metrics, qint32 lineWidth);
 
-        void decodeBitmap(QDataStream &in, QImage &bytes, int w, int h, int bpp);
-        void readASCIIString(QDataStream& ds, QString& str);
-        void readColorTable(QDataStream &in, QImage &img, int colors, int maxcolors);
-        void readColorTableAlpha(QDataStream &in, QImage &img, int colors, int maxcolors);
-        void readColorTableInv(QDataStream &in, QImage &img, int colors, int maxcolors);
-        void processTypDrawOrder(QDataStream& file, const typ_section_t& section);
-        void processTypPolygons(QDataStream& file, const typ_section_t& section);
-        void processTypPolyline(QDataStream& file, const typ_section_t& section);
-        void processTypPois(QDataStream& in, const typ_section_t& section);
-
-
-        QImage majorHighway(const QColor& color);
-        QImage residentialStreet(const QColor& color);
-        QImage principalHighway(const QColor& color);
-        QImage arterialRoad(const QColor& color);
-        QImage otherHighway(const QColor& color);
+        void drawLine(QPainter& p, CGarminPolygon& l, IGarminTyp::polyline_property& property, QFontMetricsF& metrics, QFont& font);
+        void drawLine(QPainter& p, CGarminPolygon& l);
 
 #pragma pack(1)
         struct tdb_hdr_t
@@ -205,14 +197,16 @@ class CMapTDB : public IMap
             quint8 level;
             bool useBaseMap;
 
-            bool operator==(const map_level_t &ml) {
+            bool operator==(const map_level_t &ml)
+            {
                 if (ml.bits != bits || ml.level != level || ml.useBaseMap != useBaseMap)
                     return false;
                 else
                     return true;
             }
 
-            static bool GreaterThan(const map_level_t &ml1, const map_level_t &ml2) {
+            static bool GreaterThan(const map_level_t &ml1, const map_level_t &ml2)
+            {
                 return ml1.bits < ml2.bits;
             }
         };
@@ -268,55 +262,10 @@ class CMapTDB : public IMap
         /// top bottom right as long / lat [rad]
         XY bottomRight;
 
-        QVector<QString> polyline_typestr;
-        struct polyline_property
-        {
-            polyline_property(): type(0), pen0(Qt::magenta,3)/*, pen1(Qt::NoPen)*/, known(false)/*, grow(false)*/{};
-            polyline_property(quint16 type, const QColor& color0/*, const QColor& color1*/, qreal width, Qt::PenStyle style/*, bool grow*/)
-                : type(type)
-                , pen0(QBrush(color0), width, style, Qt::RoundCap, Qt::RoundJoin)
-            //                 , pen1(QBrush(color1), width, style, Qt::RoundCap, Qt::RoundJoin)
-                , known(true)
-            //                 , grow(grow)
-                {}
-            quint16 type;
-            QPen    pen0;
-            //             QPen    pen1;
-            QFont   font;
-            bool    known;
-            //             bool    grow;
-            QImage  pixmap;
-        };
-
-        //         QVector<polyline_property> polylineProperties;
-        QMap<quint32, polyline_property> polylineProperties;
-
-        struct polygon_property
-        {
-            polygon_property() : type(0), pen(Qt::magenta), brush(Qt::magenta, Qt::BDiagPattern), known(false){}
-            polygon_property(quint16 type, const Qt::PenStyle pensty, const QColor& brushColor, Qt::BrushStyle pattern)
-                : type(type)
-                , pen(pensty)
-                , brush(brushColor, pattern)
-                , known(true)
-                {pen.setWidth(1);}
-            polygon_property(quint16 type, const QColor& penColor, const QColor& brushColor, Qt::BrushStyle pattern)
-                : type(type)
-                , pen(penColor,1)
-                , brush(brushColor, pattern)
-                , known(true)
-                {}
-            quint16 type;
-            QPen    pen;
-            QBrush  brush;
-            QFont   font;
-            bool    known;
-        };
-
-        QMap<quint32, polygon_property> polygonProperties;
-        QList<quint16> polygonDrawOrder;
-
-        QMap<quint32, QImage> pointProperties;
+        QMap<quint32, IGarminTyp::polyline_property> polylineProperties;
+        QMap<quint32, IGarminTyp::polygon_property> polygonProperties;
+        QList<quint32> polygonDrawOrder;
+        QMap<quint32, IGarminTyp::point_property> pointProperties;
 
         polytype_t polygons;
         polytype_t polylines;
@@ -333,11 +282,6 @@ class CMapTDB : public IMap
         QPoint          pointFocus;
 
         int detailsFineTune;
-        QRect   rectDecDetail;
-        QRect   rectIncDetail;
-        QRect   rectDetail;
-        bool    mouseOverDecDetail;
-        bool    mouseOverIncDetail;
 
         quint16 fid;
         quint16 pid;
@@ -366,6 +310,16 @@ class CMapTDB : public IMap
 
         bool poiLabels;
         QCheckBox * checkPoiLabels;
+        bool nightView;
+        QCheckBox * checkNightView;
+
+        QComboBox * comboDetails;
+
+        QMap<quint8, QString> languages;
+
+        QComboBox * comboLanguages;
+
+        quint8 selectedLanguage;
 
 };
 #endif                           //CMAPTDB_H
