@@ -69,7 +69,8 @@ QPolygon COverlayTextBox::makePolyline(const QPoint& anchor, const QRect& r)
     QPolygon poly1, poly2;
     poly1 << r.topLeft() << r.topRight() << r.bottomRight() << r.bottomLeft();
 
-    if(!r.contains(anchor)) {
+    if(!r.contains(anchor))
+    {
         int w = (r.width()>>1) - 50;
         int h = (r.height()>>1) - 50;
 
@@ -79,16 +80,20 @@ QPolygon COverlayTextBox::makePolyline(const QPoint& anchor, const QRect& r)
         w = w < 20 ? 20 : w;
         h = h < 20 ? 20 : h;
 
-        if(anchor.x() < r.left()) {
+        if(anchor.x() < r.left())
+        {
             poly2 << anchor << (r.center() + QPoint(0,-h)) << (r.center() + QPoint(0,h));
         }
-        else if(r.right() < anchor.x()) {
+        else if(r.right() < anchor.x())
+        {
             poly2 << anchor << (r.center() + QPoint(0,-h)) << (r.center() + QPoint(0,h));
         }
-        else if(anchor.y() < r.top()) {
+        else if(anchor.y() < r.top())
+        {
             poly2 << anchor << (r.center() + QPoint(-w,0)) << (r.center() + QPoint(w,0));
         }
-        else if(r.bottom() < anchor.y()) {
+        else if(r.bottom() < anchor.y())
+        {
             poly2 << anchor << (r.center() + QPoint(-w,0)) << (r.center() + QPoint(w,0));
         }
 
@@ -108,7 +113,8 @@ void COverlayTextBox::draw(QPainter& p)
     p.save();
     p.translate(x,y);
 
-    if(selected == this) {
+    if(selected == this)
+    {
         p.setBrush(Qt::white);
         p.setPen(QPen(Qt::red, 2));
         p.drawPolygon(polyline);
@@ -119,7 +125,8 @@ void COverlayTextBox::draw(QPainter& p)
         p.drawPixmap(rectEdit, QPixmap(":/icons/iconEdit16x16.png"));
         p.drawPixmap(rectAnchor, QPixmap(":/icons/iconMoveMap16x16.png"));
     }
-    else {
+    else
+    {
         p.setBrush(Qt::white);
         p.setPen(Qt::black);
         p.drawPolygon(polyline);
@@ -161,10 +168,12 @@ QString COverlayTextBox::getInfo()
 
     text += "\n" + doc->toPlainText();
 
-    if(text.length() < 60) {
+    if(text.length() < 60)
+    {
         return text;
     }
-    else {
+    else
+    {
         return text.left(57) + "...";
     }
 }
@@ -189,7 +198,8 @@ void COverlayTextBox::mouseMoveEvent(QMouseEvent * e)
     CMapDB::self().getMap().convertRad2Pt(x,y);
     QPoint pos = e->pos() - QPoint(x,y);
 
-    if(doMove) {
+    if(doMove)
+    {
         rect.moveTopLeft(pos);
         rectMove = QRect(rect.topLeft()     + QPoint(2,2)  , QSize(16, 16));
         rectEdit = QRect(rect.topLeft()     + QPoint(20,2) , QSize(16, 16));
@@ -203,7 +213,8 @@ void COverlayTextBox::mouseMoveEvent(QMouseEvent * e)
 
         theMainWindow->getCanvas()->update();
     }
-    else if(doSize) {
+    else if(doSize)
+    {
         rect.setBottomRight(pos);
         rectMove = QRect(rect.topLeft()     + QPoint(2,2)  , QSize(16, 16));
         rectEdit = QRect(rect.topLeft()     + QPoint(20,2) , QSize(16, 16));
@@ -217,7 +228,8 @@ void COverlayTextBox::mouseMoveEvent(QMouseEvent * e)
 
         theMainWindow->getCanvas()->update();
     }
-    else if(doPos) {
+    else if(doPos)
+    {
         rectAnchor  = QRect(pos - QPoint(8,8), QSize(16, 16));
         rectMove    = QRect(rect.topLeft()     + QPoint(2,2)  , QSize(16, 16));
         rectEdit    = QRect(rect.topLeft()     + QPoint(20,2) , QSize(16, 16));
@@ -231,14 +243,18 @@ void COverlayTextBox::mouseMoveEvent(QMouseEvent * e)
 
         theMainWindow->getCanvas()->update();
     }
-    else if(rectMove.contains(pos) || rectSize.contains(pos) || rectEdit.contains(pos) || rectDel.contains(pos) || rectAnchor.contains(pos)) {
-        if(!doSpecialCursor) {
+    else if(rectMove.contains(pos) || rectSize.contains(pos) || rectEdit.contains(pos) || rectDel.contains(pos) || rectAnchor.contains(pos))
+    {
+        if(!doSpecialCursor)
+        {
             QApplication::setOverrideCursor(Qt::PointingHandCursor);
             doSpecialCursor = true;
         }
     }
-    else {
-        if(doSpecialCursor) {
+    else
+    {
+        if(doSpecialCursor)
+        {
             QApplication::restoreOverrideCursor();
             doSpecialCursor = false;
         }
@@ -253,23 +269,28 @@ void COverlayTextBox::mousePressEvent(QMouseEvent * e)
     CMapDB::self().getMap().convertRad2Pt(x,y);
     QPoint pos = e->pos() - QPoint(x,y);
 
-    if(rectMove.contains(pos)) {
+    if(rectMove.contains(pos))
+    {
         doMove = true;
     }
-    else if(rectSize.contains(pos)) {
+    else if(rectSize.contains(pos))
+    {
         doSize = true;
     }
-    else if(rectAnchor.contains(pos)) {
+    else if(rectAnchor.contains(pos))
+    {
         doPos = true;
     }
-    else if(rectEdit.contains(pos)) {
+    else if(rectEdit.contains(pos))
+    {
         CDlgEditText dlg(text, theMainWindow->getCanvas());
         dlg.exec();
         doc->setHtml(text);
         theMainWindow->getCanvas()->update();
         emit sigChanged();
     }
-    else if(rectDel.contains(pos)) {
+    else if(rectDel.contains(pos))
+    {
         QStringList keys(key);
         COverlayDB::self().delOverlays(keys);
         QApplication::restoreOverrideCursor();
@@ -285,7 +306,8 @@ void COverlayTextBox::mouseReleaseEvent(QMouseEvent * e)
     CMapDB::self().getMap().convertRad2Pt(x,y);
     QPoint pos = e->pos() - QPoint(x,y);
 
-    if(doPos) {
+    if(doPos)
+    {
         rect.translate(-pos);
 
         polyline    = makePolyline(QPoint(0,0), rect);
@@ -302,7 +324,8 @@ void COverlayTextBox::mouseReleaseEvent(QMouseEvent * e)
         CMapDB::self().getMap().convertPt2Rad(lon, lat);
     }
 
-    if(doSize || doMove || doPos) {
+    if(doSize || doMove || doPos)
+    {
         emit sigChanged();
     }
 
