@@ -34,6 +34,8 @@ CPlot::CPlot(CPlotData::axis_type_e type, QWidget * parent)
 , top(0)
 , bottom(0)
 , fm(QFont())
+, initialYMax(0)
+, initialYMin(0)
 {
     setSizePolicy(QSizePolicy::MinimumExpanding,QSizePolicy::MinimumExpanding);
     m_pData = new CPlotData(type, this);
@@ -132,6 +134,7 @@ void CPlot::addTag(CPlotData::point_t& tag)
 void CPlot::paintEvent(QPaintEvent * )
 {
     QPainter p(this);
+    p.setRenderHint(QPainter::Antialiasing, true);
     draw(p);
 }
 
@@ -139,6 +142,10 @@ void CPlot::paintEvent(QPaintEvent * )
 void CPlot::resizeEvent(QResizeEvent * )
 {
     setSizes();
+
+    initialYMin = m_pData->y().min();
+    initialYMax = m_pData->y().max();
+
     update();
 }
 
@@ -180,7 +187,8 @@ void CPlot::setLRTB()
     right -= scaleWidthX1 / 2;
 
     top = 0;
-    if(!m_pData->tags.isEmpty()) {
+    if(!m_pData->tags.isEmpty())
+    {
         top += fontHeight;
         top += 16;
     }
@@ -209,10 +217,12 @@ void CPlot::setSizeIconArea()
 void CPlot::setSizeXLabel()
 {
     int y;
-    if ( m_pData->xlabel.isEmpty() ) {
+    if ( m_pData->xlabel.isEmpty() )
+    {
         rectX1Label = QRect( 0, 0, 0, 0 );
     }
-    else {
+    else
+    {
         rectX1Label.setWidth( right - left );
         rectX1Label.setHeight( fontHeight );
         y = ( size().height() - rectX1Label.height());
@@ -231,10 +241,12 @@ void CPlot::setSizeXLabel()
 */
 void CPlot::setSizeYLabel()
 {
-    if ( m_pData->ylabel.isEmpty() ) {
+    if ( m_pData->ylabel.isEmpty() )
+    {
         rectY1Label = QRect( 0, 0, 0, 0 );
     }
-    else {
+    else
+    {
         rectY1Label.setWidth( bottom - top );
         rectY1Label.setHeight( fontHeight );
         rectY1Label.moveTopLeft( QPoint( size().height() - bottom, 0 ) );
@@ -284,7 +296,8 @@ void CPlot::drawLabels( QPainter &p )
 {
     p.setPen(Qt::darkBlue);
 
-    if ( rectX1Label.isValid() ) {
+    if ( rectX1Label.isValid() )
+    {
         p.drawText( rectX1Label, Qt::AlignCenter, m_pData->xlabel );
     }
 
@@ -294,7 +307,8 @@ void CPlot::drawLabels( QPainter &p )
     m.rotate( -90 );
     p.setMatrix( m );
 
-    if ( rectY1Label.isValid() ) {
+    if ( rectY1Label.isValid() )
+    {
         p.drawText( rectY1Label, Qt::AlignCenter, m_pData->ylabel );
     }
     p.restore();
@@ -318,9 +332,11 @@ void CPlot::drawXScale( QPainter &p )
 
     iy = bottom + deadAreaY;
     const CPlotAxis::TTic * t = m_pData->x().ticmark();
-    while ( t ) {
+    while ( t )
+    {
         ix = left + m_pData->x().val2pt( t->val ) - ( scaleWidthX1 + 1 ) / 2;
-        if ( ( ( ix_ < 0 ) || ( ( ix - ix_ ) > scaleWidthX1 + 5 ) ) && !t->lbl.isEmpty() ) {
+        if ( ( ( ix_ < 0 ) || ( ( ix - ix_ ) > scaleWidthX1 + 5 ) ) && !t->lbl.isEmpty() )
+        {
             recText.moveTopLeft( QPoint( ix, iy ) );
             p.drawText( recText, Qt::AlignCenter, t->lbl );
             ix_ = ix;
@@ -361,7 +377,8 @@ void CPlot::drawYScale( QPainter &p )
 
     ix = left - scaleWidthY1 - deadAreaX;
     const CPlotAxis::TTic * t = m_pData->y().ticmark();
-    while ( t ) {
+    while ( t )
+    {
         iy = bottom - m_pData->y().val2pt( t->val ) - fontHeight / 2;
 
         recText.moveTopLeft( QPoint( ix, iy ) );
@@ -396,7 +413,8 @@ void CPlot::drawXTic( QPainter & p )
     p.setPen(QPen(Qt::black,2));
     iyb = rectGraphArea.bottom();
     iyt = rectGraphArea.top();
-    while ( t ) {
+    while ( t )
+    {
         ix = left + m_pData->x().val2pt( t->val );
         p.drawLine( ix, iyb, ix, iyb - 5 );
         p.drawLine( ix, iyt, ix, iyt + 5 );
@@ -414,7 +432,8 @@ void CPlot::drawYTic( QPainter &p )
     p.setPen(QPen(Qt::black,2));
     ixl = rectGraphArea.left();
     ixr = rectGraphArea.right();
-    while ( t ) {
+    while ( t )
+    {
         iy = bottom - m_pData->y().val2pt( t->val );
         p.drawLine( ixl, iy, ixl + 5, iy );
         p.drawLine( ixr, iy, ixr - 5, iy );
@@ -434,10 +453,11 @@ void CPlot::drawGridX( QPainter &p )
     const CPlotAxis::TTic * t = m_pData->x().ticmark();
 
     QPen oldpen = p.pen();
-    p.setPen( QPen( QColor(150,150,150,128), 1, Qt::DotLine ) );
+    p.setPen( QPen( QColor(0,150,0,128), 1, Qt::DotLine ) );
 
     iy = rectGraphArea.top();
-    while ( t ) {
+    while ( t )
+    {
         ix = left + m_pData->x().val2pt( t->val );
         p.drawLine( ix, iy, ix, iy + dy );
         t = m_pData->x().ticmark( t );
@@ -457,10 +477,11 @@ void CPlot::drawGridY( QPainter &p )
     const CPlotAxis::TTic * t = m_pData->y().ticmark();
 
     QPen oldpen = p.pen();
-    p.setPen( QPen( QColor(150,150,150,128), 1, Qt::DotLine ) );
+    p.setPen( QPen( QColor(0,150,0,128), 1, Qt::DotLine ) );
 
     ix = rectGraphArea.left();
-    while ( t ) {
+    while ( t )
+    {
         iy = bottom - m_pData->y().val2pt( t->val );
         p.drawLine( ix, iy, ix + dx, iy );
         t = m_pData->y().ticmark( t );
@@ -472,44 +493,74 @@ void CPlot::drawGridY( QPainter &p )
 
 QPen pens[] =
 {
-    QPen(Qt::blue,3)
-    , QPen(Qt::red,1)
+    QPen(Qt::blue,4)
+    , QPen(Qt::red,2)
     , QPen(Qt::darkYellow,2)
     , QPen(Qt::darkGreen,2)
 
 };
 
+QColor colors[] =
+{
+    QColor(0,0,255)
+    , QColor(0,0,0,0)
+    , QColor(0,0,0,0)
+    , QColor(0,0,0,0)
+
+};
+
 void CPlot::drawData(QPainter& p)
 {
     int penIdx = 0;
-    int ptx, pty, ptx_old, pty_old;
+    int ptx, pty;
     QList<CPlotData::line_t> lines                  = m_pData->lines;
     QList<CPlotData::line_t>::const_iterator line   = lines.begin();
 
     CPlotAxis& xaxis = m_pData->x();
     CPlotAxis& yaxis = m_pData->y();
 
-    while(line != lines.end()) {
+    while(line != lines.end())
+    {
+        QPolygonF background;
+        QPolygonF foreground;
 
         const QPolygonF& polyline       = line->points;
         QPolygonF::const_iterator point = polyline.begin();
 
-        ptx_old = left   + xaxis.val2pt( point->x() );
-        pty_old = bottom - yaxis.val2pt( point->y() );
+        ptx = left   + xaxis.val2pt( point->x() );
+        pty = bottom - yaxis.val2pt( point->y() );
 
-        p.setPen(pens[penIdx++]);
-        while(point != polyline.end()) {
+        background << QPointF(left,bottom);
+        background << QPointF(left,pty);
+        background << QPointF(ptx,pty);
+
+        while(point != polyline.end())
+        {
             ptx = left   + xaxis.val2pt( point->x() );
             pty = bottom - yaxis.val2pt( point->y() );
 
-            p.drawLine(ptx_old,pty_old,ptx,pty);
-
-            ptx_old = ptx;
-            pty_old = pty;
-
+            if(ptx >= left && ptx <= right)
+            {
+                background << QPointF(ptx,pty);
+                foreground << QPointF(ptx, pty);
+            }
             ++point;
         }
 
+        background << QPointF(right,pty);
+        background << QPointF(right,bottom);
+
+        QLinearGradient gradient(0, bottom - yaxis.val2pt(initialYMin), 0, bottom - yaxis.val2pt(initialYMax));
+        gradient.setColorAt(0, colors[penIdx]);
+        gradient.setColorAt(1, QColor(0,0,0,0));
+        p.setPen(Qt::NoPen);
+        p.setBrush(gradient);
+        p.drawPolygon(background);
+
+        p.setPen(pens[penIdx++]);
+        p.setBrush(Qt::NoBrush);
+        p.drawPolyline(foreground);
+
         ++line;
     }
 
@@ -518,7 +569,8 @@ void CPlot::drawData(QPainter& p)
         QPolygonF::const_iterator point = marks.begin();
         p.setPen(QPen(Qt::red,2));
 
-        while(point != marks.end()) {
+        while(point != marks.end())
+        {
             ptx = left   + xaxis.val2pt( point->x() );
             pty = bottom - yaxis.val2pt( point->y() );
 
@@ -529,7 +581,8 @@ void CPlot::drawData(QPainter& p)
         }
     }
 
-    if(!m_pData->point1.point.isNull()) {
+    if(!m_pData->point1.point.isNull())
+    {
         p.setPen(QPen(Qt::darkGreen));
         ptx = left   + xaxis.val2pt( m_pData->point1.point.x() );
         pty = bottom - yaxis.val2pt( m_pData->point1.point.y() );
@@ -554,7 +607,8 @@ void CPlot::drawLegend(QPainter& p)
     QList<CPlotData::line_t> lines                  = m_pData->lines;
     QList<CPlotData::line_t>::const_iterator line   = lines.begin();
 
-    while(line != lines.end()) {
+    while(line != lines.end())
+    {
         p.setPen(Qt::black);
         p.drawText(x + 30 ,y,line->label);
         p.setPen(pens[penIdx++]);
@@ -579,11 +633,13 @@ void CPlot::drawTags(QPainter& p)
     QFontMetrics fm(p.font());
 
     QVector<CPlotData::point_t>::const_iterator tag = m_pData->tags.begin();
-    while(tag != m_pData->tags.end()) {
+    while(tag != m_pData->tags.end())
+    {
         ptx = left   + xaxis.val2pt( tag->point.x() );
         pty = bottom - yaxis.val2pt( tag->point.y() );
 
-        if (left < ptx &&  ptx < right) {
+        if (left < ptx &&  ptx < right)
+        {
             rect = fm.boundingRect(tag->label);
             rect.moveCenter(QPoint(ptx, fontHeight / 2));
             p.setPen(Qt::darkBlue);
@@ -592,8 +648,10 @@ void CPlot::drawTags(QPainter& p)
             p.drawPixmap(ptx - tag->icon.width() / 2, fontHeight, tag->icon);
 
             p.setPen(QPen(Qt::white, 3));
-            if (fontHeight + 16 < pty) {
-                if (pty > bottom) {
+            if (fontHeight + 16 < pty)
+            {
+                if (pty > bottom)
+                {
                     pty = bottom;
                 }
 
@@ -642,6 +700,10 @@ void CPlot::resetZoom()
     m_pData->x().resetZoom();
     m_pData->y().resetZoom();
     setSizes();
+
+    initialYMin = m_pData->y().min();
+    initialYMax = m_pData->y().max();
+
     update();
 }
 
@@ -664,6 +726,7 @@ void CPlot::slotSave()
 
     QImage img(size(), QImage::Format_ARGB32);
     QPainter p;
+    p.setRenderHint(QPainter::Antialiasing, true);
 
     p.begin(&img);
     p.fillRect(rect(), QBrush(Qt::white));
@@ -711,10 +774,12 @@ void CPlot::mouseMoveEvent(QMouseEvent * e)
 
 void CPlot::mouseReleaseEvent(QMouseEvent * e)
 {
-    if (e->button() == Qt::LeftButton) {
+    if (e->button() == Qt::LeftButton)
+    {
         QApplication::restoreOverrideCursor();
     }
-    if (checkClick && e->button() == Qt::LeftButton) {
+    if (checkClick && e->button() == Qt::LeftButton)
+    {
         QPoint pos = e->pos();
         double dist = getXValByPixel(pos.x());
         emit activePointSignal(dist);
@@ -724,7 +789,8 @@ void CPlot::mouseReleaseEvent(QMouseEvent * e)
 
 void CPlot::mousePressEvent(QMouseEvent * e)
 {
-    if (e->button() == Qt::LeftButton) {
+    if (e->button() == Qt::LeftButton)
+    {
         QApplication::setOverrideCursor(QCursor(QPixmap(":/cursors/cursorMove")));
         startMovePos = e->pos();
         checkClick = true;
