@@ -22,6 +22,7 @@
 #include "CDeviceGarmin.h"
 #include "CDeviceQLandkarteM.h"
 #include "CDeviceMikrokopter.h"
+#include "CDeviceNMEA.h"
 #include "CLiveLogDB.h"
 #include "CUnitMetric.h"
 #include "CUnitNautic.h"
@@ -64,7 +65,7 @@ CResources::CResources(QObject * parent)
     m_httpProxy       = cfg.value("network/proxy/url",m_httpProxy).toString();
     m_httpProxyPort   = cfg.value("network/proxy/port",m_httpProxyPort).toUInt();
 
-    m_eBrowser        = (bowser_e)cfg.value("network/browser",m_eBrowser).toInt();
+    m_eBrowser        = (browser_e)cfg.value("network/browser",m_eBrowser).toInt();
     cmdOther          = cfg.value("network/browser/other","my command \"%s\"").toString();
 
     emit sigProxyChanged();
@@ -74,9 +75,11 @@ CResources::CResources(QObject * parent)
     m_devIPPort       = cfg.value("device/ipPort",m_devIPPort).toUInt();
     m_devSerialPort   = cfg.value("device/serialPort",m_devSerialPort).toString();
     m_devType         = cfg.value("device/type",m_devType).toString();
+    m_devCharset      = cfg.value("device/charset",m_devCharset).toString();
 
     emit sigDeviceChanged();
 
+    m_playSound       = cfg.value("device/playSound",m_playSound).toBool();
     IDevice::m_DownloadAllTrk   = cfg.value("device/dnlTrk",IDevice::m_DownloadAllTrk).toBool();
     IDevice::m_DownloadAllWpt   = cfg.value("device/dnlWpt",IDevice::m_DownloadAllWpt).toBool();
     IDevice::m_DownloadAllRte   = cfg.value("device/dnlRte",IDevice::m_DownloadAllRte).toBool();
@@ -89,13 +92,16 @@ CResources::CResources(QObject * parent)
     QString unittype = cfg.value("environment/unittype","metric").toString();
     if(unittype == "metric")
         unit = new CUnitMetric(this);
-    else if(unittype == "nautic") {
+    else if(unittype == "nautic")
+    {
         unit = new CUnitNautic(this);
     }
-    else if(unittype == "imperial") {
+    else if(unittype == "imperial")
+    {
         unit = new CUnitImperial(this);
     }
-    else {
+    else
+    {
         qWarning("Unknown unit type. Using 'metric'");
         unit = new CUnitMetric(this);
     }
@@ -126,6 +132,7 @@ CResources::~CResources()
     cfg.setValue("device/serialPort",m_devSerialPort);
     cfg.setValue("device/serialPort",m_devSerialPort);
     cfg.setValue("device/type",m_devType);
+    cfg.setValue("device/charset",m_devCharset);
 
     cfg.setValue("device/dnlTrk",IDevice::m_DownloadAllTrk);
     cfg.setValue("device/dnlWpt",IDevice::m_DownloadAllWpt);
@@ -133,6 +140,7 @@ CResources::~CResources()
     cfg.setValue("device/uplWpt",IDevice::m_UploadAllWpt);
     cfg.setValue("device/uplTrk",IDevice::m_UploadAllTrk);
     cfg.setValue("device/uplRte",IDevice::m_UploadAllRte);
+    cfg.setValue("device/playSound",m_playSound);
 
     cfg.setValue("environment/unittype",unit->type);
 }
@@ -149,30 +157,40 @@ bool CResources::getHttpProxy(QString& url, quint16& port)
 IDevice * CResources::device()
 {
     // purge device if the key does not match
-    if(m_device && (m_device->getDevKey() != m_devKey)) {
+    if(m_device && (m_device->getDevKey() != m_devKey))
+    {
         qDebug() << m_device->getDevKey() << m_devKey;
         delete m_device;
         m_device = 0;
     }
 
     // allocate new device
-    if(!m_device) {
-        if(m_devKey == "QLandkarteM") {
+    if(!m_device)
+    {
+        if(m_devKey == "QLandkarteM")
+        {
             //m_device = new CDeviceTBDOE(m_devIPAddress,m_devIPPort,this);
             m_device = new CDeviceQLandkarteM(m_devIPAddress,m_devIPPort,this);
         }
-        if(m_devKey == "Mikrokopter") {
+        if(m_devKey == "Mikrokopter")
+        {
             m_device = new CDeviceMikrokopter(m_devSerialPort, this);
         }
-        else if(m_devKey == "Garmin" && !m_devType.isEmpty()) {
+        else if(m_devKey == "Garmin" && !m_devType.isEmpty())
+        {
             m_device = new CDeviceGarmin(m_devType, m_devSerialPort, this);
         }
+        else if(m_devKey == "NMEA")
+        {
+            m_device = new CDeviceNMEA(m_devSerialPort, this);
+        }
 
         connect(m_device, SIGNAL(sigLiveLog(const CLiveLog&)), &CLiveLogDB::self(), SLOT(slotLiveLog(const CLiveLog&)));
     }
 
     // still no device?
-    if(!m_device) {
+    if(!m_device)
+    {
         qWarning() << "no device";
         // TODO: would be nicer to open the setup dialog
         QMessageBox::critical(0,tr("No device."),tr("You have to select a device in Setup->Config->Device & Xfer"), QMessageBox::Abort, QMessageBox::Abort);
@@ -182,19 +200,32 @@ IDevice * CResources::device()
 }
 
 
+QString CResources::charset()
+{
+    if (m_devCharset.isNull() || m_devCharset.isEmpty())
+        return "latin1";
+    else
+        return m_devCharset;
+}
+
+
 void CResources::openLink(const QString& link)
 {
     QString cmd;
-    if(m_eBrowser == eFirefox) {
+    if(m_eBrowser == eFirefox)
+    {
         cmd.sprintf(cmdFirefox.toAscii(),link.toAscii().data());
     }
-    else if(m_eBrowser == eKonqueror) {
+    else if(m_eBrowser == eKonqueror)
+    {
         cmd.sprintf(cmdKonqueror.toAscii(),link.toAscii().data());
     }
-    else if(m_eBrowser == eOther) {
+    else if(m_eBrowser == eOther)
+    {
         cmd.sprintf(cmdOther.toAscii(),link.toAscii().data());
     }
-    else {
+    else
+    {
         return;
     }
 
